@@ -110,6 +110,8 @@ BASE_VERSION = 1
 # v1.70: Add disable_ramdisk to manual cleaning.
 # v1.71: Add signifier for Scope based roles.
 # v1.72: Add agent_status and agent_status_message to /v1/heartbeat
+# v1.73: Add support for deploy and undeploy verbs
+# v1.74: Add bios registry to /v1/nodes/{node}/bios/{setting}
 
 MINOR_0_JUNO = 0
 MINOR_1_INITIAL_VERSION = 1
@@ -184,6 +186,8 @@ MINOR_69_DEPLOY_STEPS = 69
 MINOR_70_CLEAN_DISABLE_RAMDISK = 70
 MINOR_71_RBAC_SCOPES = 71
 MINOR_72_HEARTBEAT_STATUS = 72
+MINOR_73_DEPLOY_UNDEPLOY_VERBS = 73
+MINOR_74_BIOS_REGISTRY = 74
 
 # When adding another version, update:
 # - MINOR_MAX_VERSION
@@ -191,7 +195,7 @@ MINOR_72_HEARTBEAT_STATUS = 72
 #   explanation of what changed in the new version
 # - common/release_mappings.py, RELEASE_MAPPING['master']['api']
 
-MINOR_MAX_VERSION = MINOR_72_HEARTBEAT_STATUS
+MINOR_MAX_VERSION = MINOR_74_BIOS_REGISTRY
 
 # String representations of the minor and maximum versions
 _MIN_VERSION_STRING = '{}.{}'.format(BASE_VERSION, MINOR_1_INITIAL_VERSION)
