@@ -32,8 +32,6 @@ from osprofiler import sqlalchemy as osp_sqlalchemy
 import sqlalchemy as sa
 from sqlalchemy.orm.exc import NoResultFound, MultipleResultsFound
 from sqlalchemy.orm import joinedload
-from sqlalchemy.orm import Load
-from sqlalchemy.orm import selectinload
 from sqlalchemy import sql
 
 from ironic.common import exception
@@ -79,98 +77,16 @@ def _wrap_session(session):
     return session
 
 
-def _get_node_query_with_all_for_single_node():
+def _get_node_query_with_all():
     """Return a query object for the Node joined with all relevant fields.
 
-    This method utilizes a joined load query which creates a result set
-    where corresponding traits, and tags, are joined together in the result
-    set.
-
-    This is more efficent from a Queries Per Second standpoint with the
-    backend database, as they are not separate distinct queries which
-    are being executed by the client.
-
-    The downside of this, is the relationship of tags and traits to nodes
-    is that there may be multiple tags and traits for each node. Ultimately
-    this style of query forces SQLAlchemy to de-duplicate the result set
-    because the database returns the nodes portion of the result set for
-    every trait, tag, or other table field the query is joined with.
-    This looks like:
-
-    node1, tag1, trait1
-    node1, tag1, trait2
-    node1, tag1, trait3
-    node1, tag2, trait1
-
-    Et cetra, to create:
-
-    node1, [tag1, tag2], [trait1, trait 2, trait3]
-
-    Where joins are super in-efficent for Ironic, is where nodes are being
-    enumerated, as the above result set pattern is not just for one node, but
-    potentially thousands of nodes. In that case, we should use the
-    _get_node_query_with_all_for_list helper to return a more appropriate
-    query object which will be more efficient for the end user.
-
     :returns: a query object.
     """
-    # NOTE(TheJulia): This *likely* ought to be selectinload, however
-    # it is a very common hit pattern for Ironic to query just the node.
-    # In those sorts of locations, the performance issues are less noticable
-    # to end users. *IF/WHEN* we change it to be selectinload for nodes,
-    # the resulting DB load will see a queries per second increase, which
-    # we should be careful about.
-
-    # NOTE(TheJulia): Basic benchmark difference
-    # Test data creation: 67.202 seconds.
-    # 2.43 seconds to obtain all nodes from SQLAlchemy (10k nodes)
-    # 5.15 seconds to obtain all nodes *and* have node objects (10k nodes)
     return (model_query(models.Node)
             .options(joinedload('tags'))
             .options(joinedload('traits')))
 
 
-def _get_node_query_with_all_for_list():
-    """Return a query object for the Node with queried extra fields.
-
-    This method returns a query object joining tags and traits in a pattern
-    where the result set is first built, and then the resulting associations
-    are queried separately and the objects are reconciled by SQLAlchemy to
-    build the composite objects based upon the associations.
-
-    This results in the following query pattern when the query is executed:
-
-    select $fields from nodes where x;
-    # SQLAlchemy creates a list of associated node IDs.
-    select $fields from tags where node_id in ('1', '3', '37268');
-    select $fields from traits where node_id in ('1', '3', '37268');
-
-    SQLAlchemy then returns a result set where the tags and traits are
-    composited together efficently as opposed to having to deduplicate
-    the result set. This shifts additional load to the database which
-    was previously a high overhead operation with-in the conductor...
-    which results in a slower conductor.
-
-    :returns: a query object.
-    """
-    # NOTE(TheJulia): When comparing CI rubs *with* this being the default
-    # for all general list operations, at 10k nodes, this pattern appears
-    # to be on-par with a 5% variability between the two example benchmark
-    # tests. That being said, the test *does* not include tags or traits
-    # in it's test data set so client side deduplication is not measured.
-
-    # NOTE(TheJulia): Basic benchmark difference
-    # tests data creation: 67.117 seconds
-    # 2.32 seconds to obtain all nodes from SQLAlchemy (10k nodes)
-    # 4.99 seconds to obtain all nodes *and* have node objects (10k nodes)
-    # If this holds true, the required record deduplication with joinedload
-    # may be basically the same amount of overhead as requesting the tags
-    # and traits separately.
-    return (model_query(models.Node)
-            .options(selectinload('tags'))
-            .options(selectinload('traits')))
-
-
 def _get_deploy_template_query_with_steps():
     """Return a query object for the DeployTemplate joined with steps.
 
@@ -400,7 +316,7 @@ class Connection(api.Connection):
     _NODE_QUERY_FIELDS = {'console_enabled', 'maintenance', 'retired',
                           'driver', 'resource_class', 'provision_state',
                           'uuid', 'id', 'fault', 'conductor_group',
-                          'owner', 'lessee', 'instance_uuid'}
+                          'owner', 'lessee'}
     _NODE_IN_QUERY_FIELDS = {'%s_in' % field: field
                              for field in ('uuid', 'provision_state')}
     _NODE_NON_NULL_FILTERS = {'associated': 'instance_uuid',
@@ -517,63 +433,8 @@ class Connection(api.Connection):
                                sort_key, sort_dir, query)
 
     def get_node_list(self, filters=None, limit=None, marker=None,
-                      sort_key=None, sort_dir=None, fields=None):
-        if not fields:
-            query = _get_node_query_with_all_for_list()
-            query = self._add_nodes_filters(query, filters)
-            return _paginate_query(models.Node, limit, marker,
-                                   sort_key, sort_dir, query)
-        else:
-            # Shunt to the proper method to return the limited list.
-            return self.get_node_list_columns(columns=fields, filters=filters,
-                                              limit=limit, marker=marker,
-                                              sort_key=sort_key,
-                                              sort_dir=sort_dir)
-
-    def get_node_list_columns(self, columns=None, filters=None, limit=None,
-                              marker=None, sort_key=None, sort_dir=None):
-        """Get a node list with specific fields/columns.
-
-        :param columns: A list of columns to retrieve from the database
-                        and populate into the object.
-        :param filters: The requested database field filters in the form of
-                        a dictionary with the applicable key, and filter
-                        value.
-        :param limit: Limit the number of returned nodes, default None.
-        :param marker: Starting marker to generate a paginated result
-                       set for the consumer.
-        :param sort_key: Sort key to apply to the result set.
-        :param sort_dir: Sort direction to apply to the result set.
-        :returns: A list of Node objects based on the data model from
-                  a SQLAlchemy result set, which the object layer can
-                  use to convert the node into an Node object list.
-        """
-        traits_found = False
-        use_columns = columns[:]
-        if 'traits' in columns:
-            # Traits is synthetic in the data model and not a direct
-            # table column. As such, a different query pattern is used
-            # with SQLAlchemy.
-            traits_found = True
-            use_columns.remove('traits')
-
-        # Generate the column object list so SQLAlchemy only fulfills
-        # the requested columns.
-        use_columns = [getattr(models.Node, c) for c in use_columns]
-
-        # In essence, traits (and anything else needed to generate the
-        # composite objects) need to be reconciled without using a join
-        # as multiple rows can be generated in the result set being returned
-        # from the database server. In this case, with traits, we use
-        # a selectinload pattern.
-        if traits_found:
-            query = model_query(models.Node).options(
-                Load(models.Node).load_only(*use_columns),
-                selectinload(models.Node.traits))
-        else:
-            query = model_query(models.Node).options(
-                Load(models.Node).load_only(*use_columns))
-
+                      sort_key=None, sort_dir=None):
+        query = _get_node_query_with_all()
         query = self._add_nodes_filters(query, filters)
         return _paginate_query(models.Node, limit, marker,
                                sort_key, sort_dir, query)
@@ -618,8 +479,9 @@ class Connection(api.Connection):
     @oslo_db_api.retry_on_deadlock
     def reserve_node(self, tag, node_id):
         with _session_for_write():
-            query = _get_node_query_with_all_for_single_node()
+            query = _get_node_query_with_all()
             query = add_identity_filter(query, node_id)
+            # be optimistic and assume we usually create a reservation
             count = query.filter_by(reservation=None).update(
                 {'reservation': tag}, synchronize_session=False)
             try:
@@ -695,7 +557,7 @@ class Connection(api.Connection):
         return node
 
     def get_node_by_id(self, node_id):
-        query = _get_node_query_with_all_for_single_node()
+        query = _get_node_query_with_all()
         query = query.filter_by(id=node_id)
         try:
             return query.one()
@@ -703,7 +565,7 @@ class Connection(api.Connection):
             raise exception.NodeNotFound(node=node_id)
 
     def get_node_by_uuid(self, node_uuid):
-        query = _get_node_query_with_all_for_single_node()
+        query = _get_node_query_with_all()
         query = query.filter_by(uuid=node_uuid)
         try:
             return query.one()
@@ -711,7 +573,7 @@ class Connection(api.Connection):
             raise exception.NodeNotFound(node=node_uuid)
 
     def get_node_by_name(self, node_name):
-        query = _get_node_query_with_all_for_single_node()
+        query = _get_node_query_with_all()
         query = query.filter_by(name=node_name)
         try:
             return query.one()
@@ -722,7 +584,7 @@ class Connection(api.Connection):
         if not uuidutils.is_uuid_like(instance):
             raise exception.InvalidUUID(uuid=instance)
 
-        query = _get_node_query_with_all_for_single_node()
+        query = _get_node_query_with_all()
         query = query.filter_by(instance_uuid=instance)
 
         try:
@@ -839,7 +701,7 @@ class Connection(api.Connection):
             ref.update(values)
 
             # Return the updated node model joined with all relevant fields.
-            query = _get_node_query_with_all_for_single_node()
+            query = _get_node_query_with_all()
             query = add_identity_filter(query, node_id)
             return query.one()
 
@@ -1375,7 +1237,7 @@ class Connection(api.Connection):
         return model_query(q.exists()).scalar()
 
     def get_node_by_port_addresses(self, addresses):
-        q = _get_node_query_with_all_for_single_node()
+        q = _get_node_query_with_all()
         q = q.distinct().join(models.Port)
         q = q.filter(models.Port.address.in_(addresses))
 
@@ -1716,59 +1578,6 @@ class Connection(api.Connection):
 
         return total_to_migrate, total_migrated
 
-    @oslo_db_api.retry_on_deadlock
-    def migrate_from_iscsi_deploy(self, context, max_count, force=False):
-        """Tries to migrate away from the iscsi deploy interface.
-
-        :param context: the admin context
-        :param max_count: The maximum number of objects to migrate. Must be
-                          >= 0. If zero, all the objects will be migrated.
-        :returns: A 2-tuple, 1. the total number of objects that need to be
-                  migrated (at the beginning of this call) and 2. the number
-                  of migrated objects.
-        """
-        # TODO(dtantsur): maybe change to force=True by default in W?
-        if not force:
-            if 'direct' not in CONF.enabled_deploy_interfaces:
-                LOG.warning('The direct deploy interface is not enabled, will '
-                            'not migrate nodes to it. Run with --option '
-                            'force=true to override.')
-                return 0, 0
-
-            if CONF.default_deploy_interface == 'iscsi':
-                LOG.warning('The iscsi deploy interface is the default, will '
-                            'not migrate nodes away from it. Run with '
-                            '--option force=true to override.')
-                return 0, 0
-
-            if CONF.agent.image_download_source == 'swift':
-                LOG.warning('The direct deploy interface is using swift, will '
-                            'not migrate nodes to it. Run with --option '
-                            'force=true to override.')
-                return 0, 0
-
-        total_to_migrate = (model_query(models.Node)
-                            .filter_by(deploy_interface='iscsi')
-                            .count())
-        if not total_to_migrate:
-            return 0, 0
-
-        max_to_migrate = max_count or total_to_migrate
-
-        with _session_for_write():
-            query = (model_query(models.Node.id)
-                     .filter_by(deploy_interface='iscsi')
-                     .slice(0, max_to_migrate))
-            ids = [row[0] for row in query]
-
-            num_migrated = (model_query(models.Node)
-                            .filter_by(deploy_interface='iscsi')
-                            .filter(models.Node.id.in_(ids))
-                            .update({'deploy_interface': 'direct'},
-                                    synchronize_session=False))
-
-        return total_to_migrate, num_migrated
-
     @staticmethod
     def _verify_max_traits_per_node(node_id, num_traits):
         """Verify that an operation would not exceed the per-node trait limit.
@@ -1866,6 +1675,15 @@ class Connection(api.Connection):
                         node_id=node_id,
                         name=setting['name'],
                         value=setting['value'],
+                        attribute_type=setting.get('attribute_type'),
+                        allowable_values=setting.get('allowable_values'),
+                        lower_bound=setting.get('lower_bound'),
+                        max_length=setting.get('max_length'),
+                        min_length=setting.get('min_length'),
+                        read_only=setting.get('read_only'),
+                        reset_required=setting.get('reset_required'),
+                        unique=setting.get('unique'),
+                        upper_bound=setting.get('upper_bound'),
                         version=version)
                     bios_settings.append(bios_setting)
                     session.add(bios_setting)
@@ -1886,6 +1704,18 @@ class Connection(api.Connection):
                         node_id=node_id, name=setting['name'])
                     ref = query.one()
                     ref.update({'value': setting['value'],
+                                'attribute_type':
+                                setting.get('attribute_type'),
+                                'allowable_values':
+                                setting.get('allowable_values'),
+                                'lower_bound': setting.get('lower_bound'),
+                                'max_length': setting.get('max_length'),
+                                'min_length': setting.get('min_length'),
+                                'read_only': setting.get('read_only'),
+                                'reset_required':
+                                setting.get('reset_required'),
+                                'unique': setting.get('unique'),
+                                'upper_bound': setting.get('upper_bound'),
                                 'version': version})
                     bios_settings.append(ref)
                 session.flush()
