@@ -125,6 +125,13 @@ class Node(Base):
         schema.UniqueConstraint('instance_uuid',
                                 name='uniq_nodes0instance_uuid'),
         schema.UniqueConstraint('name', name='uniq_nodes0name'),
+        Index('owner_idx', 'owner'),
+        Index('lessee_idx', 'lessee'),
+        Index('driver_idx', 'driver'),
+        Index('provision_state_idx', 'provision_state'),
+        Index('reservation_idx', 'reservation'),
+        Index('conductor_group_idx', 'conductor_group'),
+        Index('resource_class_idx', 'resource_class'),
         table_args())
     id = Column(Integer, primary_key=True)
     uuid = Column(String(36))
@@ -332,6 +339,15 @@ class BIOSSetting(Base):
                      primary_key=True, nullable=False)
     name = Column(String(255), primary_key=True, nullable=False)
     value = Column(Text, nullable=True)
+    attribute_type = Column(String(255), nullable=True)
+    allowable_values = Column(db_types.JsonEncodedList, nullable=True)
+    lower_bound = Column(Integer, nullable=True)
+    max_length = Column(Integer, nullable=True)
+    min_length = Column(Integer, nullable=True)
+    read_only = Column(Boolean, nullable=True)
+    reset_required = Column(Boolean, nullable=True)
+    unique = Column(Boolean, nullable=True)
+    upper_bound = Column(Integer, nullable=True)
 
 
 class Allocation(Base):
