@@ -200,217 +200,13 @@ def validate_http_provisioning_configuration(node):
     deploy_utils.check_for_missing_params(params, error_msg)
 
 
-class AgentDeployMixin(agent_base.AgentDeployMixin):
+class CustomAgentDeploy(agent_base.AgentDeployMixin, agent_base.AgentBaseMixin,
+                        base.DeployInterface):
+    """A deploy interface that relies on a custom agent to deploy.
 
-    has_decomposed_deploy_steps = True
-
-    @METRICS.timer('AgentDeployMixin.write_image')
-    @base.deploy_step(priority=80)
-    @task_manager.require_exclusive_lock
-    def write_image(self, task):
-        if not task.driver.storage.should_write_image(task):
-            return
-        node = task.node
-        image_source = node.instance_info.get('image_source')
-        LOG.debug('Continuing deploy for node %(node)s with image %(img)s',
-                  {'node': node.uuid, 'img': image_source})
-
-        image_info = {
-            'id': image_source.split('/')[-1],
-            'urls': [node.instance_info['image_url']],
-            # NOTE(comstud): Older versions of ironic do not set
-            # 'disk_format' nor 'container_format', so we use .get()
-            # to maintain backwards compatibility in case code was
-            # upgraded in the middle of a build request.
-            'disk_format': node.instance_info.get('image_disk_format'),
-            'container_format': node.instance_info.get(
-                'image_container_format'),
-            'stream_raw_images': CONF.agent.stream_raw_images,
-        }
-
-        if node.instance_info.get('image_checksum'):
-            image_info['checksum'] = node.instance_info['image_checksum']
-
-        if (node.instance_info.get('image_os_hash_algo')
-                and node.instance_info.get('image_os_hash_value')):
-            image_info['os_hash_algo'] = node.instance_info[
-                'image_os_hash_algo']
-            image_info['os_hash_value'] = node.instance_info[
-                'image_os_hash_value']
-
-        proxies = {}
-        for scheme in ('http', 'https'):
-            proxy_param = 'image_%s_proxy' % scheme
-            proxy = node.driver_info.get(proxy_param)
-            if proxy:
-                proxies[scheme] = proxy
-        if proxies:
-            image_info['proxies'] = proxies
-            no_proxy = node.driver_info.get('image_no_proxy')
-            if no_proxy is not None:
-                image_info['no_proxy'] = no_proxy
-
-        image_info['node_uuid'] = node.uuid
-        iwdi = node.driver_internal_info.get('is_whole_disk_image')
-        if not iwdi:
-            for label in PARTITION_IMAGE_LABELS:
-                image_info[label] = node.instance_info.get(label)
-            boot_option = deploy_utils.get_boot_option(node)
-            image_info['deploy_boot_mode'] = (
-                boot_mode_utils.get_boot_mode(node))
-            image_info['boot_option'] = boot_option
-            disk_label = deploy_utils.get_disk_label(node)
-            if disk_label is not None:
-                image_info['disk_label'] = disk_label
-
-        has_write_image = agent_base.find_step(
-            task, 'deploy', 'deploy', 'write_image') is not None
-        if not has_write_image:
-            LOG.warning('The agent on node %s does not have the deploy '
-                        'step deploy.write_image, using the deprecated '
-                        'synchronous fall-back', task.node.uuid)
-
-        if self.has_decomposed_deploy_steps and has_write_image:
-            configdrive = node.instance_info.get('configdrive')
-            # Now switch into the corresponding in-band deploy step and let the
-            # result be polled normally.
-            new_step = {'interface': 'deploy',
-                        'step': 'write_image',
-                        'args': {'image_info': image_info,
-                                 'configdrive': configdrive}}
-            return agent_base.execute_step(task, new_step, 'deploy',
-                                           client=self._client)
-        else:
-            # TODO(dtantsur): remove in W
-            command = self._client.prepare_image(node, image_info, wait=True)
-            if command['command_status'] == 'FAILED':
-                # TODO(jimrollenhagen) power off if using neutron dhcp to
-                #                      align with pxe driver?
-                msg = (_('node %(node)s command status errored: %(error)s') %
-                       {'node': node.uuid, 'error': command['command_error']})
-                LOG.error(msg)
-                deploy_utils.set_failed_state(task, msg)
-
-    # TODO(dtantsur): remove in W
-    def _get_uuid_from_result(self, task, type_uuid):
-        command = self._client.get_last_command_status(task.node,
-                                                       'prepare_image')
-        if (not command
-                or not command.get('command_result', {}).get('result')):
-            msg = _('Unexpected response from the agent for node %s: the '
-                    'running command list does not include prepare_image '
-                    'or its result is malformed') % task.node.uuid
-            LOG.error(msg)
-            deploy_utils.set_failed_state(task, msg)
-            return
-
-        words = command['command_result']['result'].split()
-        for word in words:
-            if type_uuid in word:
-                result = word.split('=')[1]
-                if not result:
-                    msg = (_('Command result did not return %(type_uuid)s '
-                             'for node %(node)s. The version of the IPA '
-                             'ramdisk used in the deployment might not '
-                             'have support for provisioning of '
-                             'partition images.') %
-                           {'type_uuid': type_uuid,
-                            'node': task.node.uuid})
-                    LOG.error(msg)
-                    deploy_utils.set_failed_state(task, msg)
-                    return
-                return result
-
-    @METRICS.timer('AgentDeployMixin.prepare_instance_boot')
-    @base.deploy_step(priority=60)
-    @task_manager.require_exclusive_lock
-    def prepare_instance_boot(self, task):
-        if not task.driver.storage.should_write_image(task):
-            task.driver.boot.prepare_instance(task)
-            # Move straight to the final steps
-            return
-
-        node = task.node
-        iwdi = task.node.driver_internal_info.get('is_whole_disk_image')
-        cpu_arch = task.node.properties.get('cpu_arch')
-
-        # If `boot_option` is set to `netboot`, PXEBoot.prepare_instance()
-        # would need root_uuid of the whole disk image to add it into the
-        # pxe config to perform chain boot.
-        # IPA would have returned us the 'root_uuid_or_disk_id' if image
-        # being provisioned is a whole disk image. IPA would also provide us
-        # 'efi_system_partition_uuid' if the image being provisioned is a
-        # partition image.
-        # In case of local boot using partition image, we need both
-        # 'root_uuid_or_disk_id' and 'efi_system_partition_uuid' to configure
-        # bootloader for local boot.
-        # NOTE(mjturek): In the case of local boot using a partition image on
-        # ppc64* hardware we need to provide the 'PReP_Boot_partition_uuid' to
-        # direct where the bootloader should be installed.
-        driver_internal_info = task.node.driver_internal_info
-        try:
-            partition_uuids = self._client.get_partition_uuids(node).get(
-                'command_result') or {}
-            root_uuid = partition_uuids.get('root uuid')
-        except exception.AgentAPIError:
-            # TODO(dtantsur): remove in W
-            LOG.warning('Old ironic-python-agent detected, please update '
-                        'to Victoria or newer')
-            partition_uuids = None
-            root_uuid = self._get_uuid_from_result(task, 'root_uuid')
-
-        if root_uuid:
-            driver_internal_info['root_uuid_or_disk_id'] = root_uuid
-            task.node.driver_internal_info = driver_internal_info
-            task.node.save()
-        elif not iwdi:
-            LOG.error('No root UUID returned from the ramdisk for node '
-                      '%(node)s, the deploy will likely fail. Partition '
-                      'UUIDs are %(uuids)s',
-                      {'node': node.uuid, 'uuid': partition_uuids})
-
-        efi_sys_uuid = None
-        if not iwdi:
-            if boot_mode_utils.get_boot_mode(node) == 'uefi':
-                # TODO(dtantsur): remove in W
-                if partition_uuids is None:
-                    efi_sys_uuid = (self._get_uuid_from_result(task,
-                                    'efi_system_partition_uuid'))
-                else:
-                    efi_sys_uuid = partition_uuids.get(
-                        'efi system partition uuid')
-
-        prep_boot_part_uuid = None
-        if cpu_arch is not None and cpu_arch.startswith('ppc64'):
-            # TODO(dtantsur): remove in W
-            if partition_uuids is None:
-                prep_boot_part_uuid = (self._get_uuid_from_result(task,
-                                       'PReP_Boot_partition_uuid'))
-            else:
-                prep_boot_part_uuid = partition_uuids.get(
-                    'PReP Boot partition uuid')
-
-        LOG.info('Image successfully written to node %s', node.uuid)
-
-        if CONF.agent.manage_agent_boot:
-            # It is necessary to invoke prepare_instance() of the node's
-            # boot interface, so that the any necessary configurations like
-            # setting of the boot mode (e.g. UEFI secure boot) which cannot
-            # be done on node during deploy stage can be performed.
-            LOG.debug('Executing driver specific tasks before booting up the '
-                      'instance for node %s', node.uuid)
-            self.prepare_instance_to_boot(task, root_uuid,
-                                          efi_sys_uuid, prep_boot_part_uuid)
-        else:
-            manager_utils.node_set_boot_device(task, 'disk', persistent=True)
-
-        # Remove symbolic link when deploy is done.
-        deploy_utils.remove_http_instance_symlink(task.node.uuid)
-
-
-class AgentDeploy(AgentDeployMixin, agent_base.AgentBaseMixin,
-                  base.DeployInterface):
-    """Interface for deploy-related actions."""
+    Only provides the basic deploy steps to start the ramdisk, tear down
+    the ramdisk and prepare the instance boot.
+    """
 
     def get_properties(self):
         """Return the properties of the interface.
@@ -423,7 +219,7 @@ class AgentDeploy(AgentDeployMixin, agent_base.AgentBaseMixin,
         """Whether agent boot is managed by ironic."""
         return CONF.agent.manage_agent_boot
 
-    @METRICS.timer('AgentDeploy.validate')
+    @METRICS.timer('CustomAgentDeploy.validate')
     def validate(self, task):
         """Validate the driver-specific Node deployment info.
 
@@ -440,65 +236,11 @@ class AgentDeploy(AgentDeployMixin, agent_base.AgentBaseMixin,
         if CONF.agent.manage_agent_boot:
             task.driver.boot.validate(task)
 
-        node = task.node
-
-        # Validate node capabilities
-        deploy_utils.validate_capabilities(node)
-
-        if not task.driver.storage.should_write_image(task):
-            # NOTE(TheJulia): There is no reason to validate
-            # image properties if we will not be writing an image
-            # in a boot from volume case. As such, return to the caller.
-            LOG.debug('Skipping complete deployment interface validation '
-                      'for node %s as it is set to boot from a remote '
-                      'volume.', node.uuid)
-            return
-
-        params = {}
-        image_source = node.instance_info.get('image_source')
-        image_checksum = node.instance_info.get('image_checksum')
-        image_disk_format = node.instance_info.get('image_disk_format')
-        os_hash_algo = node.instance_info.get('image_os_hash_algo')
-        os_hash_value = node.instance_info.get('image_os_hash_value')
-
-        params['instance_info.image_source'] = image_source
-        error_msg = _('Node %s failed to validate deploy image info. Some '
-                      'parameters were missing') % node.uuid
-
-        deploy_utils.check_for_missing_params(params, error_msg)
-
-        # NOTE(dtantsur): glance images contain a checksum; for file images we
-        # will recalculate the checksum anyway.
-        if (not service_utils.is_glance_image(image_source)
-                and not image_source.startswith('file://')):
-
-            def _raise_missing_checksum_exception(node):
-                raise exception.MissingParameterValue(_(
-                    'image_source\'s "image_checksum", or '
-                    '"image_os_hash_algo" and "image_os_hash_value" '
-                    'must be provided in instance_info for '
-                    'node %s') % node.uuid)
-
-            if os_hash_value and not os_hash_algo:
-                # We are missing a piece of information,
-                # so we still need to raise an error.
-                _raise_missing_checksum_exception(node)
-            elif not os_hash_value and os_hash_algo:
-                # We have the hash setting, but not the hash.
-                _raise_missing_checksum_exception(node)
-            elif not os_hash_value and not image_checksum:
-                # We are lacking the original image_checksum,
-                # so we raise the error.
-                _raise_missing_checksum_exception(node)
-
-        validate_http_provisioning_configuration(node)
-
-        check_image_size(task, image_source, image_disk_format)
+        deploy_utils.validate_capabilities(task.node)
         # Validate the root device hints
-        deploy_utils.get_root_device_for_deploy(node)
-        validate_image_proxies(node)
+        deploy_utils.get_root_device_for_deploy(task.node)
 
-    @METRICS.timer('AgentDeploy.deploy')
+    @METRICS.timer('CustomAgentDeploy.deploy')
     @base.deploy_step(priority=100)
     @task_manager.require_exclusive_lock
     def deploy(self, task):
@@ -532,7 +274,34 @@ class AgentDeploy(AgentDeployMixin, agent_base.AgentBaseMixin,
             task.node.save()
             return states.DEPLOYWAIT
 
-    @METRICS.timer('AgentDeploy.prepare')
+    @METRICS.timer('CustomAgentDeployMixin.prepare_instance_boot')
+    @base.deploy_step(priority=60)
+    @task_manager.require_exclusive_lock
+    def prepare_instance_boot(self, task):
+        """Prepare instance for booting.
+
+        The base version only calls prepare_instance on the boot interface.
+        """
+        try:
+            task.driver.boot.prepare_instance(task)
+        except Exception as e:
+            LOG.error('Preparing instance for booting failed for node '
+                      '%(node)s. %(cls)s: %(error)s',
+                      {'node': task.node.uuid,
+                       'cls': e.__class__.__name__, 'error': e})
+            msg = _('Failed to prepare instance for booting')
+            agent_base.log_and_raise_deployment_error(task, msg, exc=e)
+
+    def _update_instance_info(self, task):
+        """Update instance information with extra data for deploy.
+
+        Called from `prepare` to populate fields that can be deduced from
+        the already provided information.
+
+        Does nothing in the base class.
+        """
+
+    @METRICS.timer('CustomAgentDeploy.prepare')
     @task_manager.require_exclusive_lock
     def prepare(self, task):
         """Prepare the deployment environment for this node.
@@ -552,11 +321,6 @@ class AgentDeploy(AgentDeployMixin, agent_base.AgentBaseMixin,
         :raises: any boot interface's prepare_ramdisk exceptions.
         """
 
-        def _update_instance_info():
-            node.instance_info = (
-                deploy_utils.build_instance_info_for_deploy(task))
-            node.save()
-
         node = task.node
         deploy_utils.populate_storage_driver_internal_info(task)
         if node.provision_state == states.DEPLOYING:
@@ -617,7 +381,7 @@ class AgentDeploy(AgentDeployMixin, agent_base.AgentBaseMixin,
                         task, power_state_to_restore)
                 else:
                     # Fast track sequence in progress
-                    _update_instance_info()
+                    self._update_instance_info(task)
             # Signal to storage driver to attach volumes
             task.driver.storage.attach_volumes(task)
             if (not task.driver.storage.should_write_image(task)
@@ -634,12 +398,12 @@ class AgentDeploy(AgentDeployMixin, agent_base.AgentBaseMixin,
         elif node.provision_state != states.ADOPTING:
             if node.provision_state not in (states.RESCUING, states.RESCUEWAIT,
                                             states.RESCUE, states.RESCUEFAIL):
-                _update_instance_info()
+                self._update_instance_info(task)
             if CONF.agent.manage_agent_boot:
                 deploy_opts = deploy_utils.build_agent_options(node)
                 task.driver.boot.prepare_ramdisk(task, deploy_opts)
 
-    @METRICS.timer('AgentDeploy.clean_up')
+    @METRICS.timer('CustomAgentDeploy.clean_up')
     @task_manager.require_exclusive_lock
     def clean_up(self, task):
         """Clean up the deployment environment for this node.
@@ -657,10 +421,230 @@ class AgentDeploy(AgentDeployMixin, agent_base.AgentBaseMixin,
 
         :param task: a TaskManager instance.
         """
-        super(AgentDeploy, self).clean_up(task)
+        super().clean_up(task)
         deploy_utils.destroy_http_instance_images(task.node)
 
 
+class AgentDeploy(CustomAgentDeploy):
+    """Interface for deploy-related actions."""
+
+    def _update_instance_info(self, task):
+        """Update instance information with extra data for deploy."""
+        task.node.instance_info = (
+            deploy_utils.build_instance_info_for_deploy(task))
+        task.node.save()
+
+    @METRICS.timer('AgentDeploy.validate')
+    def validate(self, task):
+        """Validate the driver-specific Node deployment info.
+
+        This method validates whether the properties of the supplied node
+        contain the required information for this driver to deploy images to
+        the node.
+
+        :param task: a TaskManager instance
+        :raises: MissingParameterValue, if any of the required parameters are
+            missing.
+        :raises: InvalidParameterValue, if any of the parameters have invalid
+            value.
+        """
+        super().validate(task)
+
+        node = task.node
+
+        if not task.driver.storage.should_write_image(task):
+            # NOTE(TheJulia): There is no reason to validate
+            # image properties if we will not be writing an image
+            # in a boot from volume case. As such, return to the caller.
+            LOG.debug('Skipping complete deployment interface validation '
+                      'for node %s as it is set to boot from a remote '
+                      'volume.', node.uuid)
+            return
+        params = {}
+        image_source = node.instance_info.get('image_source')
+        image_checksum = node.instance_info.get('image_checksum')
+        image_disk_format = node.instance_info.get('image_disk_format')
+        os_hash_algo = node.instance_info.get('image_os_hash_algo')
+        os_hash_value = node.instance_info.get('image_os_hash_value')
+
+        params['instance_info.image_source'] = image_source
+        error_msg = _('Node %s failed to validate deploy image info. Some '
+                      'parameters were missing') % node.uuid
+
+        deploy_utils.check_for_missing_params(params, error_msg)
+
+        # NOTE(dtantsur): glance images contain a checksum; for file images we
+        # will recalculate the checksum anyway.
+        if (not service_utils.is_glance_image(image_source)
+                and not image_source.startswith('file://')):
+
+            def _raise_missing_checksum_exception(node):
+                raise exception.MissingParameterValue(_(
+                    'image_source\'s "image_checksum", or '
+                    '"image_os_hash_algo" and "image_os_hash_value" '
+                    'must be provided in instance_info for '
+                    'node %s') % node.uuid)
+
+            if os_hash_value and not os_hash_algo:
+                # We are missing a piece of information,
+                # so we still need to raise an error.
+                _raise_missing_checksum_exception(node)
+            elif not os_hash_value and os_hash_algo:
+                # We have the hash setting, but not the hash.
+                _raise_missing_checksum_exception(node)
+            elif not os_hash_value and not image_checksum:
+                # We are lacking the original image_checksum,
+                # so we raise the error.
+                _raise_missing_checksum_exception(node)
+
+        validate_http_provisioning_configuration(node)
+
+        check_image_size(task, image_source, image_disk_format)
+        validate_image_proxies(node)
+
+    @METRICS.timer('AgentDeployMixin.write_image')
+    @base.deploy_step(priority=80)
+    @task_manager.require_exclusive_lock
+    def write_image(self, task):
+        if not task.driver.storage.should_write_image(task):
+            return
+        node = task.node
+        image_source = node.instance_info.get('image_source')
+        LOG.debug('Continuing deploy for node %(node)s with image %(img)s',
+                  {'node': node.uuid, 'img': image_source})
+
+        image_info = {
+            'id': image_source.split('/')[-1],
+            'urls': [node.instance_info['image_url']],
+            # NOTE(comstud): Older versions of ironic do not set
+            # 'disk_format' nor 'container_format', so we use .get()
+            # to maintain backwards compatibility in case code was
+            # upgraded in the middle of a build request.
+            'disk_format': node.instance_info.get('image_disk_format'),
+            'container_format': node.instance_info.get(
+                'image_container_format'),
+            'stream_raw_images': CONF.agent.stream_raw_images,
+        }
+
+        if node.instance_info.get('image_checksum'):
+            image_info['checksum'] = node.instance_info['image_checksum']
+
+        if (node.instance_info.get('image_os_hash_algo')
+                and node.instance_info.get('image_os_hash_value')):
+            image_info['os_hash_algo'] = node.instance_info[
+                'image_os_hash_algo']
+            image_info['os_hash_value'] = node.instance_info[
+                'image_os_hash_value']
+
+        proxies = {}
+        for scheme in ('http', 'https'):
+            proxy_param = 'image_%s_proxy' % scheme
+            proxy = node.driver_info.get(proxy_param)
+            if proxy:
+                proxies[scheme] = proxy
+        if proxies:
+            image_info['proxies'] = proxies
+            no_proxy = node.driver_info.get('image_no_proxy')
+            if no_proxy is not None:
+                image_info['no_proxy'] = no_proxy
+
+        image_info['node_uuid'] = node.uuid
+        iwdi = node.driver_internal_info.get('is_whole_disk_image')
+        if not iwdi:
+            for label in PARTITION_IMAGE_LABELS:
+                image_info[label] = node.instance_info.get(label)
+            boot_option = deploy_utils.get_boot_option(node)
+            image_info['deploy_boot_mode'] = (
+                boot_mode_utils.get_boot_mode(node))
+            image_info['boot_option'] = boot_option
+            disk_label = deploy_utils.get_disk_label(node)
+            if disk_label is not None:
+                image_info['disk_label'] = disk_label
+
+        configdrive = manager_utils.get_configdrive_image(node)
+        if configdrive:
+            # FIXME(dtantsur): remove this duplication once IPA is ready:
+            # https://review.opendev.org/c/openstack/ironic-python-agent/+/790471
+            image_info['configdrive'] = configdrive
+        # Now switch into the corresponding in-band deploy step and let the
+        # result be polled normally.
+        new_step = {'interface': 'deploy',
+                    'step': 'write_image',
+                    'args': {'image_info': image_info,
+                             'configdrive': configdrive}}
+        return agent_base.execute_step(task, new_step, 'deploy',
+                                       client=self._client)
+
+    @METRICS.timer('AgentDeployMixin.prepare_instance_boot')
+    @base.deploy_step(priority=60)
+    @task_manager.require_exclusive_lock
+    def prepare_instance_boot(self, task):
+        if not task.driver.storage.should_write_image(task):
+            task.driver.boot.prepare_instance(task)
+            # Move straight to the final steps
+            return
+
+        node = task.node
+        iwdi = task.node.driver_internal_info.get('is_whole_disk_image')
+        cpu_arch = task.node.properties.get('cpu_arch')
+
+        # If `boot_option` is set to `netboot`, PXEBoot.prepare_instance()
+        # would need root_uuid of the whole disk image to add it into the
+        # pxe config to perform chain boot.
+        # IPA would have returned us the 'root_uuid_or_disk_id' if image
+        # being provisioned is a whole disk image. IPA would also provide us
+        # 'efi_system_partition_uuid' if the image being provisioned is a
+        # partition image.
+        # In case of local boot using partition image, we need both
+        # 'root_uuid_or_disk_id' and 'efi_system_partition_uuid' to configure
+        # bootloader for local boot.
+        # NOTE(mjturek): In the case of local boot using a partition image on
+        # ppc64* hardware we need to provide the 'PReP_Boot_partition_uuid' to
+        # direct where the bootloader should be installed.
+        driver_internal_info = task.node.driver_internal_info
+        partition_uuids = self._client.get_partition_uuids(node).get(
+            'command_result') or {}
+        root_uuid = partition_uuids.get('root uuid')
+
+        if root_uuid:
+            driver_internal_info['root_uuid_or_disk_id'] = root_uuid
+            task.node.driver_internal_info = driver_internal_info
+            task.node.save()
+        elif not iwdi:
+            LOG.error('No root UUID returned from the ramdisk for node '
+                      '%(node)s, the deploy will likely fail. Partition '
+                      'UUIDs are %(uuids)s',
+                      {'node': node.uuid, 'uuid': partition_uuids})
+
+        efi_sys_uuid = None
+        if not iwdi:
+            if boot_mode_utils.get_boot_mode(node) == 'uefi':
+                efi_sys_uuid = partition_uuids.get(
+                    'efi system partition uuid')
+
+        prep_boot_part_uuid = None
+        if cpu_arch is not None and cpu_arch.startswith('ppc64'):
+            prep_boot_part_uuid = partition_uuids.get(
+                'PReP Boot partition uuid')
+
+        LOG.info('Image successfully written to node %s', node.uuid)
+
+        if CONF.agent.manage_agent_boot:
+            # It is necessary to invoke prepare_instance() of the node's
+            # boot interface, so that the any necessary configurations like
+            # setting of the boot mode (e.g. UEFI secure boot) which cannot
+            # be done on node during deploy stage can be performed.
+            LOG.debug('Executing driver specific tasks before booting up the '
+                      'instance for node %s', node.uuid)
+            self.prepare_instance_to_boot(task, root_uuid,
+                                          efi_sys_uuid, prep_boot_part_uuid)
+        else:
+            manager_utils.node_set_boot_device(task, 'disk', persistent=True)
+
+        # Remove symbolic link when deploy is done.
+        deploy_utils.remove_http_instance_symlink(task.node.uuid)
+
+
 class AgentRAID(base.RAIDInterface):
     """Implementation of RAIDInterface which uses agent ramdisk."""
 
