@@ -14,7 +14,6 @@
 
 from http import client as http_client
 import os
-import ssl
 
 from ironic_lib import metrics_utils
 from oslo_log import log
@@ -25,7 +24,6 @@ import tenacity
 
 from ironic.common import exception
 from ironic.common.i18n import _
-from ironic.common import utils
 from ironic.conf import CONF
 
 LOG = log.getLogger(__name__)
@@ -37,15 +35,6 @@ DEFAULT_IPA_PORTAL_PORT = 3260
 REBOOT_COMMAND = 'run_image'
 
 
-def get_client(task):
-    """Get client for this node."""
-    try:
-        return task.cached_agent_client
-    except AttributeError:
-        task.cached_agent_client = AgentClient()
-        return task.cached_agent_client
-
-
 def get_command_error(command):
     """Extract an error string from the command result.
 
@@ -64,15 +53,6 @@ def get_command_error(command):
         return error
 
 
-def _sanitize_for_logging(var):
-    if not var:
-        return var
-    elif isinstance(var, str):
-        return strutils.mask_password(var)
-    else:
-        return utils.remove_large_keys(strutils.mask_dict_password(var))
-
-
 class AgentClient(object):
     """Client for interacting with nodes via a REST API."""
     @METRICS.timer('AgentClient.__init__')
@@ -190,17 +170,15 @@ class AgentClient(object):
         agent_token = node.driver_internal_info.get('agent_secret_token')
         if agent_token:
             request_params['agent_token'] = agent_token
-        LOG.debug('Executing agent command %(method)s for node %(node)s '
-                  'with params %(params)s',
-                  {'node': node.uuid, 'method': method,
-                   'params': _sanitize_for_logging(request_params)})
+        LOG.debug('Executing agent command %(method)s for node %(node)s',
+                  {'node': node.uuid, 'method': method})
 
         try:
             response = self.session.post(
                 url, params=request_params, data=body,
                 verify=self._get_verify(node),
                 timeout=CONF.agent.command_timeout)
-        except (requests.ConnectionError, requests.Timeout, ssl.SSLError) as e:
+        except (requests.ConnectionError, requests.Timeout) as e:
             result = self._handle_timeout_on_command_execution(node, method,
                                                                params, e)
             response = None
@@ -230,7 +208,7 @@ class AgentClient(object):
         LOG.debug('Agent command %(method)s for node %(node)s returned '
                   'result %(res)s, error %(error)s, HTTP status code %(code)s',
                   {'node': node.uuid, 'method': method,
-                   'res': _sanitize_for_logging(result.get('command_result')),
+                   'res': result.get('command_result'),
                    'error': error,
                    'code': response.status_code if response is not None
                    else 'unknown'})
@@ -335,8 +313,7 @@ class AgentClient(object):
         result = _get().json()['commands']
         status = '; '.join('%(cmd)s: result "%(res)s", error "%(err)s"' %
                            {'cmd': r.get('command_name'),
-                            'res': _sanitize_for_logging(
-                                r.get('command_result')),
+                            'res': r.get('command_result'),
                             'err': r.get('command_error')}
                            for r in result)
         LOG.debug('Status of agent commands for node %(node)s: %(status)s',
@@ -421,66 +398,6 @@ class AgentClient(object):
                       {'cmd': method, 'node': node.uuid})
             return None
 
-    @METRICS.timer('AgentClient.prepare_image')
-    def prepare_image(self, node, image_info, wait=False):
-        """Call the `prepare_image` method on the node.
-
-        :param node: A Node object.
-        :param image_info: A dictionary containing various image related
-                           information.
-        :param wait: True to wait for the command to finish executing, False
-                     otherwise.
-        :raises: IronicException when failed to issue the request or there was
-                 a malformed response from the agent.
-        :raises: AgentAPIError when agent failed to execute specified command.
-        :raises: AgentInProgress when the command fails to execute as the agent
-                 is presently executing the prior command.
-        :returns: A dict containing command status from agent.
-                  See :func:`get_commands_status` for a command result sample.
-        """
-        LOG.debug('Preparing image %(image)s on node %(node)s.',
-                  {'image': image_info.get('id'),
-                   'node': node.uuid})
-        params = {'image_info': image_info}
-
-        # this should be an http(s) URL
-        configdrive = node.instance_info.get('configdrive')
-        if configdrive is not None:
-            params['configdrive'] = configdrive
-
-        return self._command(node=node,
-                             method='standby.prepare_image',
-                             params=params,
-                             poll=wait)
-
-    @METRICS.timer('AgentClient.start_iscsi_target')
-    def start_iscsi_target(self, node, iqn,
-                           portal_port=DEFAULT_IPA_PORTAL_PORT,
-                           wipe_disk_metadata=False):
-        """Expose the node's disk as an ISCSI target.
-
-        :param node: an Ironic node object
-        :param iqn: iSCSI target IQN
-        :param portal_port: iSCSI portal port
-        :param wipe_disk_metadata: True if the agent should wipe first the
-                                   disk magic strings like the partition
-                                   table, RAID or filesystem signature.
-        :raises: IronicException when failed to issue the request or there was
-                 a malformed response from the agent.
-        :raises: AgentAPIError when agent failed to execute specified command.
-        :raises: AgentInProgress when the command fails to execute as the agent
-                 is presently executing the prior command.
-        :returns: A dict containing command response from agent.
-                  See :func:`get_commands_status` for a command result sample.
-        """
-        params = {'iqn': iqn,
-                  'portal_port': portal_port,
-                  'wipe_disk_metadata': wipe_disk_metadata}
-        return self._command(node=node,
-                             method='iscsi.start_iscsi_target',
-                             params=params,
-                             wait=True)
-
     @METRICS.timer('AgentClient.install_bootloader')
     def install_bootloader(self, node, root_uuid, target_boot_mode,
                            efi_system_part_uuid=None,
