@@ -79,12 +79,12 @@ OPTIONAL_PROPERTIES = {
                               "iLO.")
 }
 KERNEL_PARAM_PROPERTIES = {
-    'ilo_kernel_append_params': _("Additional kernel parameters to pass down "
-                                  "to instance kernel. These parameters can "
-                                  "be consumed by the kernel or by the "
-                                  "applications by reading /proc/cmdline. "
-                                  "Mind severe cmdline size limit. Overrides "
-                                  "[ilo]/kernel_append_params ironic option.")
+    'kernel_append_params': _("Additional kernel parameters to pass down "
+                              "to instance kernel. These parameters can "
+                              "be consumed by the kernel or by the "
+                              "applications by reading /proc/cmdline. "
+                              "Mind severe cmdline size limit. Overrides "
+                              "[ilo]/kernel_append_params ironic option.")
 }
 COMMON_PROPERTIES = REQUIRED_PROPERTIES
 VMEDIA_OPTIONAL_PROPERTIES = OPTIONAL_PROPERTIES.copy()
@@ -420,7 +420,14 @@ class IloVirtualMediaBoot(base.BootInterface):
         """
 
         node = task.node
-        if not driver_utils.need_prepare_ramdisk(node):
+        # NOTE(TheJulia): If this method is being called by something
+        # aside from deployment, clean and rescue, such as conductor takeover,
+        # we should treat this as a no-op and move on otherwise we would
+        # modify the state of the node due to virtual media operations.
+        if node.provision_state not in (states.DEPLOYING,
+                                        states.CLEANING,
+                                        states.RESCUING,
+                                        states.INSPECTING):
             return
 
         prepare_node_for_deploy(task)
@@ -1059,7 +1066,14 @@ class IloUefiHttpsBoot(base.BootInterface):
         :raises: IloOperationError, if some operation on iLO failed.
         """
         node = task.node
-        if not driver_utils.need_prepare_ramdisk(node):
+        # NOTE(TheJulia): If this method is being called by something
+        # aside from deployment, clean and rescue, such as conductor takeover,
+        # we should treat this as a no-op and move on otherwise we would
+        # modify the state of the node due to virtual media operations.
+        if node.provision_state not in (states.DEPLOYING,
+                                        states.CLEANING,
+                                        states.RESCUING,
+                                        states.INSPECTING):
             return
 
         prepare_node_for_deploy(task)
