@@ -28,12 +28,12 @@ from oslo_log import log
 from ironic.common import exception
 from ironic.common.i18n import _
 from ironic.common import images
-from ironic.common import states
 from ironic.common import swift
 from ironic.common import utils
 from ironic.conf import CONF
 from ironic.drivers.modules import boot_mode_utils
 from ironic.drivers.modules import deploy_utils
+from ironic.drivers import utils as driver_utils
 
 LOG = log.getLogger(__name__)
 
@@ -424,12 +424,6 @@ def _prepare_iso_image(task, kernel_href, ramdisk_href,
             "building ISO, or explicit ISO for %(node)s") %
             {'node': task.node.uuid})
 
-    i_info = task.node.instance_info
-    is_ramdisk_boot = (
-        task.node.provision_state == states.DEPLOYING
-        and deploy_utils.get_boot_option(task.node) == 'ramdisk'
-    )
-
     # NOTE(rpittau): if base_iso is defined as http address, we just access
     # it directly.
     if base_iso and CONF.deploy.ramdisk_image_download_source == 'http':
@@ -440,13 +434,12 @@ def _prepare_iso_image(task, kernel_href, ramdisk_href,
                   {"boot_iso": base_iso})
 
     img_handler = ImageHandler(task.node.driver)
-    k_param = img_handler.kernel_params
 
     i_info = task.node.instance_info
 
     # NOTE(TheJulia): Until we support modifying a base iso, most of
     # this logic actually does nothing in the end. But it should!
-    if is_ramdisk_boot:
+    if deploy_utils.get_boot_option(task.node) == "ramdisk":
         if not base_iso:
             kernel_params = "root=/dev/ram0 text "
             kernel_params += i_info.get("ramdisk_kernel_arguments", "")
@@ -454,13 +447,13 @@ def _prepare_iso_image(task, kernel_href, ramdisk_href,
             kernel_params = None
 
     else:
-        kernel_params = i_info.get('kernel_append_params', k_param)
+        kernel_params = driver_utils.get_kernel_append_params(
+            task.node, default=img_handler.kernel_params)
 
     if params and not base_iso:
         kernel_params = ' '.join(
             (kernel_params, ' '.join(
-                ('%s=%s' % kv) if kv[1] is not None else kv[0]
-                for kv in params.items())))
+                '%s=%s' % kv for kv in params.items())))
 
     boot_mode = boot_mode_utils.get_boot_mode(task.node)
 
