@@ -51,9 +51,19 @@ RESCUE_PROPERTIES = {
                         'that is used at node rescue time. This value is '
                         'required for rescue mode.'),
 }
+OPTIONAL_PROPERTIES = {
+    'kernel_append_params': _("Additional kernel parameters to pass down to "
+                              "instance kernel. These parameters can be "
+                              "consumed by the kernel or by the applications "
+                              "by reading /proc/cmdline. Mind severe cmdline "
+                              "size limit. Overrides "
+                              "[pxe]/kernel_append_params ironic "
+                              "option."),
+}
 COMMON_PROPERTIES = REQUIRED_PROPERTIES.copy()
 COMMON_PROPERTIES.update(driver_utils.OPTIONAL_PROPERTIES)
 COMMON_PROPERTIES.update(RESCUE_PROPERTIES)
+COMMON_PROPERTIES.update(OPTIONAL_PROPERTIES)
 
 
 class PXEBaseMixin(object):
@@ -420,7 +430,7 @@ class PXEBaseMixin(object):
         elif service_utils.is_glance_image(d_info['image_source']):
             props = ['kernel_id', 'ramdisk_id']
             if boot_option == 'kickstart':
-                props.append('stage2_id')
+                props.append('squashfs_id')
         else:
             props = ['kernel', 'ramdisk']
         deploy_utils.validate_image_properties(task.context, d_info, props)
