@@ -35,9 +35,11 @@ LOG = log.getLogger(__name__)
 
 REQUIRED_PROPERTIES = {
     'deploy_kernel': _("URL or Glance UUID of the deployment kernel. "
-                       "Required."),
-    'deploy_ramdisk': _("URL or Glance UUID of the ramdisk that is "
-                        "mounted at boot time. Required.")
+                       "Required if deploy_iso is not set."),
+    'deploy_ramdisk': _("URL or Glance UUID of the ramdisk that is mounted at "
+                        "boot time. Required if deploy_iso is not set."),
+    'deploy_iso': _("URL or Glance UUID of the deployment ISO to use. "
+                    "Required if deploy_kernel/deploy_ramdisk are not set.")
 }
 
 OPTIONAL_PROPERTIES = {
@@ -56,16 +58,19 @@ OPTIONAL_PROPERTIES = {
                     "image containing EFI boot loader. This image will be "
                     "used by ironic when building UEFI-bootable ISO "
                     "out of kernel and ramdisk. Required for UEFI "
-                    "boot from partition images."),
+                    "when deploy_iso is not provided."),
 
 }
 
 RESCUE_PROPERTIES = {
-    'rescue_kernel': _('URL or Glance UUID of the rescue kernel. This value '
-                       'is required for rescue mode.'),
+    'rescue_kernel': _('URL or Glance UUID of the rescue kernel. Required for '
+                       'rescue mode if rescue_iso is not set.'),
     'rescue_ramdisk': _('URL or Glance UUID of the rescue ramdisk with agent '
-                        'that is used at node rescue time. This value is '
-                        'required for rescue mode.'),
+                        'that is used at node rescue time. Required for '
+                        'rescue mode if rescue_iso is not set.'),
+    'rescue_iso': _("URL or Glance UUID of the rescue ISO to use. Required "
+                    "for rescue mode if rescue_kernel/rescue_ramdisk are "
+                    "not set.")
 }
 
 COMMON_PROPERTIES = REQUIRED_PROPERTIES.copy()
@@ -73,11 +78,6 @@ COMMON_PROPERTIES.update(driver_utils.OPTIONAL_PROPERTIES)
 COMMON_PROPERTIES.update(OPTIONAL_PROPERTIES)
 COMMON_PROPERTIES.update(RESCUE_PROPERTIES)
 
-KERNEL_RAMDISK_LABELS = {
-    'deploy': REQUIRED_PROPERTIES,
-    'rescue': RESCUE_PROPERTIES
-}
-
 IMAGE_SUBDIR = 'redfish'
 
 sushy = importutils.try_import('sushy')
@@ -100,23 +100,15 @@ def _parse_driver_info(node):
     d_info = node.driver_info
 
     mode = deploy_utils.rescue_or_deploy_mode(node)
-    iso_param = 'redfish_%s_iso' % mode
-    iso_ref = d_info.get(iso_param)
+    iso_param = f'{mode}_iso'
+    iso_ref = driver_utils.get_agent_iso(node, deprecated_prefix='redfish',
+                                         mode=mode)
     if iso_ref is not None:
         deploy_info = {iso_param: iso_ref}
         can_config = False
     else:
-        params_to_check = KERNEL_RAMDISK_LABELS[mode]
-
-        deploy_info = {option: d_info.get(option)
-                       for option in params_to_check}
-
-        if not any(deploy_info.values()):
-            # NOTE(dtantsur): avoid situation when e.g. deploy_kernel comes
-            # from driver_info but deploy_ramdisk comes from configuration,
-            # since it's a sign of a potential operator's mistake.
-            deploy_info = {k: getattr(CONF.conductor, k)
-                           for k in params_to_check}
+        # There was never a deprecated prefix for kernel/ramdisk
+        deploy_info = driver_utils.get_agent_kernel_ramdisk(node, mode)
 
         error_msg = _("Error validating Redfish virtual media. Some "
                       "parameters were missing in node's driver_info")
@@ -230,11 +222,9 @@ def _eject_vmedia(task, managers, boot_device=None):
     :param boot_device: sushy boot device e.g. `VIRTUAL_MEDIA_CD`,
         `VIRTUAL_MEDIA_DVD` or `VIRTUAL_MEDIA_FLOPPY` or `None` to
         eject everything (default).
-    :return: True if any device was ejected, else False
     :raises: InvalidParameterValue, if no suitable virtual CD or DVD is
         found on the node.
     """
-    found = False
     for manager in managers:
         for v_media in manager.virtual_media.get_members():
             if boot_device and boot_device not in v_media.media_types:
@@ -244,14 +234,12 @@ def _eject_vmedia(task, managers, boot_device=None):
 
             if inserted:
                 v_media.eject_media()
-                found = True
 
             LOG.info("Boot media is%(already)s ejected from "
                      "%(boot_device)s for node %(node)s"
                      "", {'node': task.node.uuid,
                           'already': '' if inserted else ' already',
                           'boot_device': v_media.name})
-    return found
 
 
 def eject_vmedia(task, boot_device=None):
@@ -265,15 +253,7 @@ def eject_vmedia(task, boot_device=None):
         found on the node.
     """
     system = redfish_utils.get_system(task.node)
-    if _eject_vmedia(task, system.managers, boot_device=boot_device):
-        LOG.debug('Cleaning up unused files after ejecting %(dev)s for node '
-                  '%(node)s', {'dev': boot_device or 'all devices',
-                               'node': task.node.uuid})
-        if (boot_device is None
-                or boot_device == sushy.VIRTUAL_MEDIA_USBSTICK):
-            image_utils.cleanup_disk_image(task, prefix='configdrive')
-        if boot_device is None or boot_device == sushy.VIRTUAL_MEDIA_CD:
-            image_utils.cleanup_iso_image(task)
+    _eject_vmedia(task, system.managers, boot_device=boot_device)
 
 
 def _has_vmedia_device(managers, boot_device, inserted=None):
@@ -390,6 +370,8 @@ class RedfishVirtualMediaBoot(base.BootInterface):
         node = task.node
 
         _parse_driver_info(node)
+        # Issue the deprecation warning if needed
+        driver_utils.get_agent_iso(node, deprecated_prefix='redfish')
 
     def _validate_instance_info(self, task):
         """Validate instance image information for the task's node.
@@ -425,34 +407,18 @@ class RedfishVirtualMediaBoot(base.BootInterface):
 
         deploy_utils.validate_image_properties(task.context, d_info, props)
 
-    def _validate_vendor(self, task, managers):
-        """Validates vendor specific requirements for the task's node.
-
-        :param task: a TaskManager instance containing the node to act on.
-        :param managers: Redfish managers for Redfish system associated
-            with node.
-        :raises: InvalidParameterValue if vendor not supported
-        """
+    def _validate_vendor(self, task):
         vendor = task.node.properties.get('vendor')
         if not vendor:
             return
 
         if 'Dell' in vendor.split():
-            # Check if iDRAC fw >= 6.00.00.00 that supports virtual media boot
-            bmc_manager = [m for m in managers
-                           if m.manager_type == sushy.MANAGER_TYPE_BMC]
-            if bmc_manager:
-                fwv = bmc_manager[0].firmware_version.split('.')
-                if int(fwv[0]) >= 6:
-                    return
             raise exception.InvalidParameterValue(
                 _("The %(iface)s boot interface is not suitable for node "
-                  "%(node)s with vendor %(vendor)s and BMC version %(fwv)s, "
-                  "upgrade to 6.00.00.00 or newer or use "
+                  "%(node)s with vendor %(vendor)s, use "
                   "idrac-redfish-virtual-media instead")
                 % {'iface': task.node.boot_interface,
-                   'node': task.node.uuid, 'vendor': vendor,
-                   'fwv': bmc_manager[0].firmware_version})
+                   'node': task.node.uuid, 'vendor': vendor})
 
     def validate(self, task):
         """Validate the deployment information for the task's node.
@@ -465,6 +431,7 @@ class RedfishVirtualMediaBoot(base.BootInterface):
         :raises: InvalidParameterValue on malformed parameter(s)
         :raises: MissingParameterValue on missing parameter(s)
         """
+        self._validate_vendor(task)
         self._validate_driver_info(task)
         self._validate_instance_info(task)
 
@@ -501,14 +468,19 @@ class RedfishVirtualMediaBoot(base.BootInterface):
             operation failed on the node.
         """
         node = task.node
-        if not driver_utils.need_prepare_ramdisk(node):
+        # NOTE(TheJulia): If this method is being called by something
+        # aside from deployment, clean and rescue, such as conductor takeover,
+        # we should treat this as a no-op and move on otherwise we would
+        # modify the state of the node due to virtual media operations.
+        if node.provision_state not in (states.DEPLOYING,
+                                        states.CLEANING,
+                                        states.RESCUING,
+                                        states.INSPECTING):
             return
 
         d_info = _parse_driver_info(node)
         managers = redfish_utils.get_system(task.node).managers
 
-        self._validate_vendor(task, managers)
-
         if manager_utils.is_fast_track(task):
             if _has_vmedia_device(managers, sushy.VIRTUAL_MEDIA_CD,
                                   inserted=True):
@@ -658,21 +630,12 @@ class RedfishVirtualMediaBoot(base.BootInterface):
         managers = redfish_utils.get_system(task.node).managers
 
         deploy_info = _parse_deploy_info(node)
-        configdrive = node.instance_info.get('configdrive')
         iso_ref = image_utils.prepare_boot_iso(task, deploy_info, **params)
         _eject_vmedia(task, managers, sushy.VIRTUAL_MEDIA_CD)
         _insert_vmedia(task, managers, iso_ref, sushy.VIRTUAL_MEDIA_CD)
 
-        if configdrive and boot_option == 'ramdisk':
-            _eject_vmedia(task, managers, sushy.VIRTUAL_MEDIA_USBSTICK)
-            cd_ref = image_utils.prepare_configdrive_image(task, configdrive)
-            try:
-                _insert_vmedia(task, managers, cd_ref,
-                               sushy.VIRTUAL_MEDIA_USBSTICK)
-            except exception.InvalidParameterValue:
-                raise exception.InstanceDeployFailure(
-                    _('Cannot attach configdrive for node %s: no suitable '
-                      'virtual USB slot has been found') % node.uuid)
+        if boot_option == 'ramdisk':
+            self._attach_configdrive(task, managers)
 
         del managers
 
@@ -682,6 +645,21 @@ class RedfishVirtualMediaBoot(base.BootInterface):
                   "%(device)s", {'node': task.node.uuid,
                                  'device': boot_devices.CDROM})
 
+    def _attach_configdrive(self, task, managers):
+        configdrive = manager_utils.get_configdrive_image(task.node)
+        if not configdrive:
+            return
+
+        _eject_vmedia(task, managers, sushy.VIRTUAL_MEDIA_USBSTICK)
+        cd_ref = image_utils.prepare_configdrive_image(task, configdrive)
+        try:
+            _insert_vmedia(task, managers, cd_ref,
+                           sushy.VIRTUAL_MEDIA_USBSTICK)
+        except exception.InvalidParameterValue:
+            raise exception.InstanceDeployFailure(
+                _('Cannot attach configdrive for node %s: no suitable '
+                  'virtual USB slot has been found') % task.node.uuid)
+
     def _eject_all(self, task):
         managers = redfish_utils.get_system(task.node).managers
 
@@ -698,7 +676,7 @@ class RedfishVirtualMediaBoot(base.BootInterface):
 
         boot_option = deploy_utils.get_boot_option(task.node)
         if (boot_option == 'ramdisk'
-                and task.node.instance_info.get('configdrive')):
+                and task.node.instance_info.get('configdrive') is not None):
             _eject_vmedia(task, managers, sushy.VIRTUAL_MEDIA_USBSTICK)
             image_utils.cleanup_disk_image(task, prefix='configdrive')
 
