@@ -12,7 +12,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import itertools
 import math
 
 from futurist import periodics
@@ -23,8 +22,6 @@ from oslo_utils import units
 
 from ironic.common import exception
 from ironic.common.i18n import _
-from ironic.common import raid as raid_common
-from ironic.common import raid
 from ironic.common import states
 from ironic.conductor import task_manager
 from ironic.conductor import utils as manager_utils
@@ -93,12 +90,6 @@ RAID_LEVELS = {
 
 sushy = importutils.try_import('sushy')
 
-if sushy:
-    PROTOCOL_MAP = {
-        sushy.PROTOCOL_TYPE_SAS: raid.SAS,
-        sushy.PROTOCOL_TYPE_SATA: raid.SATA
-    }
-
 
 def convert_drive_units(logical_disks, node):
     """Convert size in logical_disks from gb to bytes"""
@@ -121,7 +112,7 @@ def convert_drive_units(logical_disks, node):
 
 
 def get_physical_disks(node):
-    """Get the physical drives of the node for RAID controllers.
+    """Get the physical drives of the node.
 
     :param node: an ironic node object.
     :returns: a list of Drive objects from sushy
@@ -131,24 +122,22 @@ def get_physical_disks(node):
     system = redfish_utils.get_system(node)
 
     disks = []
-    disk_to_storage = {}
+    disk_to_controller = {}
     try:
         collection = system.storage
         for storage in collection.get_members():
+            disks.extend(storage.drives)
             controller = (storage.storage_controllers[0]
                           if storage.storage_controllers else None)
-            if controller and controller.raid_types == []:
-                continue
-            disks.extend(storage.drives)
             for drive in storage.drives:
-                disk_to_storage[drive] = storage
+                disk_to_controller[drive] = controller
     except sushy.exceptions.SushyError as exc:
         error_msg = _('Cannot get the list of physical disks for node '
                       '%(node_uuid)s. Reason: %(error)s.' %
                       {'node_uuid': node.uuid, 'error': exc})
         LOG.error(error_msg)
         raise exception.RedfishError(error=exc)
-    return disks, disk_to_storage
+    return disks, disk_to_controller
 
 
 def _raise_raid_level_not_supported(raid_level):
@@ -253,7 +242,7 @@ def _calculate_spans(raid_level, disks_count):
 
 
 def _calculate_volume_props(logical_disk, physical_disks, free_space_bytes,
-                            disk_to_storage):
+                            disk_to_controller):
     """Calculate specific properties of the volume and update logical_disk dict
 
     Calculates various properties like span_depth and span_length for the
@@ -265,7 +254,7 @@ def _calculate_volume_props(logical_disk, physical_disks, free_space_bytes,
            specified by the operator.
     :param physical_disks: list of drives available on the node.
     :param free_space_bytes: dict mapping drives to their available space.
-    :param disk_to_storage: dict mapping drives to their storage.
+    :param disk_to_controller: dict mapping drives to their controller.
     :raises: RedfishError if physical drives cannot fulfill the logical disk.
     """
     # TODO(billdodd): match e.g. {'size': '> 100'} -> oslo_utils.specs_matcher
@@ -330,9 +319,10 @@ def _calculate_volume_props(logical_disk, physical_disks, free_space_bytes,
             free_space_bytes[disk] -= disk_usage
 
     if 'controller' not in logical_disk:
-        storage = disk_to_storage[selected_disks[0]]
-        if storage:
-            logical_disk['controller'] = storage.identity
+        controller = disk_to_controller[selected_disks[0]]
+        if controller and controller.identifiers:
+            durable_name = controller.identifiers[0].durable_name
+            logical_disk['controller'] = durable_name
 
 
 def _raid_level_min_disks(raid_level, spans_count=1):
@@ -389,7 +379,7 @@ def _usable_disks_count(raid_level, disks_count):
 
 
 def _assign_disks_to_volume(logical_disks, physical_disks_by_type,
-                            free_space_bytes, disk_to_storage):
+                            free_space_bytes, disk_to_controller):
     logical_disk = logical_disks.pop(0)
     raid_level = logical_disk['raid_level']
 
@@ -401,7 +391,7 @@ def _assign_disks_to_volume(logical_disks, physical_disks_by_type,
             continue
         if ('interface_type' in logical_disk
                 and logical_disk['interface_type'].lower()
-                != PROTOCOL_MAP[protocol].lower()):
+                != protocol.lower()):
             continue
 
         # filter out disks without free disk space
@@ -447,7 +437,7 @@ def _assign_disks_to_volume(logical_disks, physical_disks_by_type,
             try:
                 _calculate_volume_props(candidate_volume, selected_disks,
                                         candidate_free_space_bytes,
-                                        disk_to_storage)
+                                        disk_to_controller)
             except exception.RedfishError as exc:
                 LOG.debug('Caught RedfishError in _calculate_volume_props(). '
                           'Reason: %s', exc)
@@ -459,7 +449,7 @@ def _assign_disks_to_volume(logical_disks, physical_disks_by_type,
                         _assign_disks_to_volume(logical_disks,
                                                 physical_disks_by_type,
                                                 candidate_free_space_bytes,
-                                                disk_to_storage))
+                                                disk_to_controller))
                 except exception.RedfishError as exc:
                     LOG.debug('Caught RedfishError in '
                               '_assign_disks_to_volume(). Reason: %s', exc)
@@ -476,7 +466,7 @@ def _assign_disks_to_volume(logical_disks, physical_disks_by_type,
         return False, free_space_bytes
 
 
-def _find_configuration(logical_disks, physical_disks, disk_to_storage):
+def _find_configuration(logical_disks, physical_disks, disk_to_controller):
     """Find RAID configuration.
 
     This method transforms the RAID configuration defined in Ironic to a format
@@ -539,7 +529,7 @@ def _find_configuration(logical_disks, physical_disks, disk_to_storage):
                    if ('physical_disks' in volume
                        and volume['size_bytes'] != 'MAX')]:
         _calculate_volume_props(volume, physical_disks, free_space_bytes,
-                                disk_to_storage)
+                                disk_to_controller)
         processed_volumes.append(volume)
 
     # step 2 - process volumes without predefined disks
@@ -550,7 +540,7 @@ def _find_configuration(logical_disks, physical_disks, disk_to_storage):
         result, free_space_bytes = (
             _assign_disks_to_volume(volumes_without_disks,
                                     physical_disks_by_type, free_space_bytes,
-                                    disk_to_storage))
+                                    disk_to_controller))
         if not result:
             # try again using the reserved physical disks in addition
             for disk_type, disks in physical_disks_by_type.items():
@@ -561,7 +551,7 @@ def _find_configuration(logical_disks, physical_disks, disk_to_storage):
                 _assign_disks_to_volume(volumes_without_disks,
                                         physical_disks_by_type,
                                         free_space_bytes,
-                                        disk_to_storage))
+                                        disk_to_controller))
             if not result:
                 error_msg = _('failed to find matching physical disks for all '
                               'logical disks')
@@ -577,7 +567,7 @@ def _find_configuration(logical_disks, physical_disks, disk_to_storage):
                    if ('physical_disks' in volume
                        and volume['size_bytes'] == 'MAX')]:
         _calculate_volume_props(volume, physical_disks, free_space_bytes,
-                                disk_to_storage)
+                                disk_to_controller)
         processed_volumes.append(volume)
 
     return processed_volumes
@@ -599,11 +589,6 @@ def _filter_logical_disks(logical_disks, include_root_volume,
 def _get_storage_controller(node, system, physical_disks):
     collection = system.storage
     for storage in collection.get_members():
-        # Using first controller as expecting only one
-        controller = (storage.storage_controllers[0]
-                      if storage.storage_controllers else None)
-        if controller and controller.raid_types == []:
-            continue
         for drive in storage.drives:
             if drive.identity in physical_disks:
                 return storage
@@ -686,38 +671,6 @@ def create_virtual_disk(task, raid_controller, physical_disks, raid_level,
         raise exception.RedfishError(error=exc)
 
 
-def update_raid_config(node):
-    """Updates node's raid_config field with current logical disks.
-
-    :param node: node for which to update the raid_config field
-    """
-    system = redfish_utils.get_system(node)
-    logical_disks = []
-    vol_no_raid_type = []
-    for stor in system.storage.get_members():
-        for vol in stor.volumes.get_members():
-            if vol.raid_type:
-                logical_disk = {
-                    'id': vol.identity,
-                    'name': vol.name,
-                    'controller': stor.identity,
-                    'size_gb': int(vol.capacity_bytes / units.Gi),
-                    'raid_level': next(
-                        key for key, value in RAID_LEVELS.items()
-                        if value['raid_type'] == vol.raid_type)
-                }
-                logical_disks.append(logical_disk)
-            else:
-                vol_no_raid_type.append(vol.identity)
-
-    if vol_no_raid_type:
-        LOG.warning("Unable to update raid_config for volumes missing RAID "
-                    "type: %(vol_no_raid_type)s",
-                    {'vol_no_raid_type': ", ".join(vol_no_raid_type)})
-
-    raid_common.update_raid_info(node, {'logical_disks': logical_disks})
-
-
 class RedfishRAID(base.RAIDInterface):
 
     def __init__(self):
@@ -734,23 +687,31 @@ class RedfishRAID(base.RAIDInterface):
         """
         return redfish_utils.COMMON_PROPERTIES.copy()
 
-    def validate_raid_config(self, task, raid_config):
-        """Validates the given RAID configuration.
+    def _validate_vendor(self, task):
+        vendor = task.node.properties.get('vendor')
+        if not vendor:
+            return
+
+        if 'dell' in vendor.lower().split():
+            raise exception.InvalidParameterValue(
+                _("The %(iface)s raid interface is not suitable for node "
+                  "%(node)s with vendor %(vendor)s, use idrac-redfish instead")
+                % {'iface': task.node.raid_interface,
+                   'node': task.node.uuid, 'vendor': vendor})
+
+    def validate(self, task):
+        """Validates the RAID Interface.
+
+        This method validates the properties defined by Ironic for RAID
+        configuration. Driver implementations of this interface can override
+        this method for doing more validations (such as BMC's credentials).
 
         :param task: A TaskManager instance.
-        :param raid_config: The RAID configuration to validate.
         :raises: InvalidParameterValue, if the RAID configuration is invalid.
+        :raises: MissingParameterValue, if some parameters are missing.
         """
-
-        super(RedfishRAID, self).validate_raid_config(task, raid_config)
-
-        # Check if any interface_type is scsi that is not supported by Redfish
-        scsi_disks = ([x for x in raid_config['logical_disks']
-                      if x.get('interface_type') == raid.SCSI])
-
-        if len(scsi_disks) > 0:
-            raise exception.InvalidParameterValue(
-                _('interface type `scsi` not supported by Redfish RAID'))
+        self._validate_vendor(task)
+        super(RedfishRAID, self).validate(task)
 
     @base.deploy_step(priority=0,
                       argsinfo=base.RAID_APPLY_CONFIGURATION_ARGSINFO)
@@ -813,25 +774,44 @@ class RedfishRAID(base.RAIDInterface):
 
         logical_disks = node.target_raid_config['logical_disks']
         convert_drive_units(logical_disks, node)
-        physical_disks, disk_to_storage = get_physical_disks(node)
+        physical_disks, disk_to_controller = get_physical_disks(node)
         # TODO(billdodd): filter out physical disks that are already in use?
         #                 filter out disks with HotSpareType != "None"?
         logical_disks = _find_configuration(logical_disks, physical_disks,
-                                            disk_to_storage)
+                                            disk_to_controller)
 
         logical_disks_to_create = _filter_logical_disks(
             logical_disks, create_root_volume, create_nonroot_volumes)
 
         self.pre_create_configuration(task, logical_disks_to_create)
 
-        # Group logical disks by controller
-        def gb_key(x):
-            return x.get('controller')
-        gb_list = itertools.groupby(
-            sorted(logical_disks_to_create, key=gb_key), gb_key)
-        ld_grouped = {k: list(g) for k, g in gb_list}
-        raid_configs, reboot_required = self._submit_create_configuration(
-            task, ld_grouped)
+        reboot_required = False
+        raid_configs = list()
+        for logical_disk in logical_disks_to_create:
+            raid_config = dict()
+            response = create_virtual_disk(
+                task,
+                raid_controller=logical_disk.get('controller'),
+                physical_disks=logical_disk['physical_disks'],
+                raid_level=logical_disk['raid_level'],
+                size_bytes=logical_disk['size_bytes'],
+                disk_name=logical_disk.get('name'),
+                span_length=logical_disk.get('span_length'),
+                span_depth=logical_disk.get('span_depth'),
+                error_handler=self.volume_create_error_handler)
+            # only save the async tasks (task_monitors) in raid_config
+            if (response is not None
+                    and hasattr(response, 'task_monitor_uri')):
+                raid_config['operation'] = 'create'
+                raid_config['raid_controller'] = logical_disk.get(
+                    'controller')
+                raid_config['task_monitor_uri'] = response.task_monitor_uri
+                reboot_required = True
+                raid_configs.append(raid_config)
+
+        driver_internal_info = node.driver_internal_info
+        driver_internal_info['raid_configs'] = raid_configs
+        node.driver_internal_info = driver_internal_info
 
         return_state = None
         deploy_utils.set_async_step_flags(
@@ -844,8 +824,6 @@ class RedfishRAID(base.RAIDInterface):
             deploy_opts = deploy_utils.build_agent_options(task.node)
             task.driver.boot.prepare_ramdisk(task, deploy_opts)
             manager_utils.node_power_action(task, states.REBOOT)
-        else:
-            update_raid_config(node)
 
         return self.post_create_configuration(
             task, raid_configs, return_state=return_state)
@@ -861,8 +839,55 @@ class RedfishRAID(base.RAIDInterface):
             complete.
         """
         node = task.node
-        raid_configs, reboot_required = self._submit_delete_configuration(
-            task)
+        system = redfish_utils.get_system(node)
+        vols_to_delete = []
+        try:
+            for storage in system.storage.get_members():
+                controller = (storage.storage_controllers[0]
+                              if storage.storage_controllers else None)
+                controller_name = None
+                if controller and controller.identifiers:
+                    controller_name = controller.identifiers[0].durable_name
+                for volume in storage.volumes.get_members():
+                    if (volume.raid_type or volume.volume_type not in
+                            [None, sushy.VOLUME_TYPE_RAW_DEVICE]):
+                        vols_to_delete.append((storage.volumes, volume,
+                                               controller_name))
+        except sushy.exceptions.SushyError as exc:
+            error_msg = _('Cannot get the list of volumes to delete for node '
+                          '%(node_uuid)s. Reason: %(error)s.' %
+                          {'node_uuid': node.uuid, 'error': exc})
+            LOG.error(error_msg)
+            raise exception.RedfishError(error=exc)
+
+        self.pre_delete_configuration(task, vols_to_delete)
+
+        reboot_required = False
+        raid_configs = list()
+        for vol_coll, volume, controller_name in vols_to_delete:
+            raid_config = dict()
+            apply_time = None
+            apply_time_support = vol_coll.operation_apply_time_support
+            if (apply_time_support
+                    and apply_time_support.mapped_supported_values):
+                supported_values = apply_time_support.mapped_supported_values
+                if sushy.APPLY_TIME_IMMEDIATE in supported_values:
+                    apply_time = sushy.APPLY_TIME_IMMEDIATE
+                elif sushy.APPLY_TIME_ON_RESET in supported_values:
+                    apply_time = sushy.APPLY_TIME_ON_RESET
+            response = volume.delete(apply_time=apply_time)
+            # only save the async tasks (task_monitors) in raid_config
+            if (response is not None
+                    and hasattr(response, 'task_monitor_uri')):
+                raid_config['operation'] = 'delete'
+                raid_config['raid_controller'] = controller_name
+                raid_config['task_monitor_uri'] = response.task_monitor_uri
+                reboot_required = True
+                raid_configs.append(raid_config)
+
+        driver_internal_info = node.driver_internal_info
+        driver_internal_info['raid_configs'] = raid_configs
+        node.driver_internal_info = driver_internal_info
 
         return_state = None
         deploy_utils.set_async_step_flags(
@@ -875,8 +900,6 @@ class RedfishRAID(base.RAIDInterface):
             deploy_opts = deploy_utils.build_agent_options(task.node)
             task.driver.boot.prepare_ramdisk(task, deploy_opts)
             manager_utils.node_power_action(task, states.REBOOT)
-        else:
-            update_raid_config(node)
 
         return self.post_delete_configuration(
             task, raid_configs, return_state=return_state)
@@ -978,15 +1001,6 @@ class RedfishRAID(base.RAIDInterface):
         for (node_uuid, driver, conductor_group,
              driver_internal_info) in node_list:
             try:
-                raid_configs = driver_internal_info.get(
-                    'raid_configs')
-                # NOTE(TheJulia): Evaluate the presence of raid configuration
-                # activity before pulling the task, so we don't needlessly
-                # create database queries with tasks which would be skipped
-                # anyhow.
-                if not raid_configs:
-                    continue
-
                 lock_purpose = 'checking async RAID config failed.'
                 with task_manager.acquire(context, node_uuid,
                                           purpose=lock_purpose,
@@ -994,6 +1008,11 @@ class RedfishRAID(base.RAIDInterface):
                     if not isinstance(task.driver.raid, RedfishRAID):
                         continue
 
+                    raid_configs = driver_internal_info.get(
+                        'raid_configs')
+                    if not raid_configs:
+                        continue
+
                     node = task.node
 
                     # A RAID config failed. Discard any remaining RAID
@@ -1006,7 +1025,6 @@ class RedfishRAID(base.RAIDInterface):
 
                     task.upgrade_lock()
                     self._clear_raid_configs(node)
-                    update_raid_config(task.node)
 
             except exception.NodeNotFound:
                 LOG.info('During _query_raid_config_failed, node '
@@ -1031,14 +1049,6 @@ class RedfishRAID(base.RAIDInterface):
         for (node_uuid, driver, conductor_group,
              driver_internal_info) in node_list:
             try:
-                raid_configs = driver_internal_info.get(
-                    'raid_configs')
-                # NOTE(TheJulia): Skip to next record if we do not
-                # have raid configuraiton tasks, so we don't pull tasks
-                # for every unrelated node in CLEANWAIT.
-                if not raid_configs:
-                    continue
-
                 lock_purpose = 'checking async RAID config tasks.'
                 with task_manager.acquire(context, node_uuid,
                                           purpose=lock_purpose,
@@ -1046,6 +1056,11 @@ class RedfishRAID(base.RAIDInterface):
                     if not isinstance(task.driver.raid, RedfishRAID):
                         continue
 
+                    raid_configs = driver_internal_info.get(
+                        'raid_configs')
+                    if not raid_configs:
+                        continue
+
                     self._check_node_raid_config(task)
 
             except exception.NodeNotFound:
@@ -1057,221 +1072,74 @@ class RedfishRAID(base.RAIDInterface):
                          '%(node)s was already locked by another process. '
                          'Skip.', {'node': node_uuid})
 
-    def _raid_config_in_progress(self, task, task_monitor_uri, operation):
-        """Check if this RAID configuration operation is still in progress.
+    def _get_error_messages(self, response):
+        try:
+            body = response.json()
+        except ValueError:
+            return []
+        else:
+            error = body.get('error', {})
+            code = error.get('code', '')
+            message = error.get('message', code)
+            ext_info = error.get('@Message.ExtendedInfo', [{}])
+            messages = [m.get('Message') for m in ext_info if 'Message' in m]
+            if not messages and message:
+                messages = [message]
+            return messages
 
-        :param task: TaskManager object containing the node.
-        :param task_monitor_uri: Redfish task monitor URI
-        :param operation: 'create' or 'delete' operation for given task.
-            Used in log messages.
-        :returns: True, if still in progress, otherwise False.
-        """
+    def _raid_config_in_progress(self, task, raid_config):
+        """Check if this RAID configuration operation is still in progress."""
+        task_monitor_uri = raid_config['task_monitor_uri']
         try:
             task_monitor = redfish_utils.get_task_monitor(task.node,
                                                           task_monitor_uri)
         except exception.RedfishError:
-            LOG.info('Unable to get status of RAID %(operation)s task '
-                     '%(task_mon_uri)s to node %(node_uuid)s; assuming task '
-                     'completed successfully',
-                     {'operation': operation,
-                      'task_mon_uri': task_monitor_uri,
+            LOG.info('Unable to get status of RAID %(operation)s task to node '
+                     '%(node_uuid)s; assuming task completed successfully',
+                     {'operation': raid_config['operation'],
                       'node_uuid': task.node.uuid})
             return False
         if task_monitor.is_processing:
-            LOG.debug('RAID %(operation)s task %(task_mon_uri)s to node '
+            LOG.debug('RAID %(operation)s task %(task_mon)s to node '
                       '%(node_uuid)s still in progress',
-                      {'operation': operation,
-                       'task_mon_uri': task_monitor.task_monitor_uri,
+                      {'operation': raid_config['operation'],
+                       'task_mon': task_monitor.task_monitor_uri,
                        'node_uuid': task.node.uuid})
             return True
         else:
-            sushy_task = task_monitor.get_task()
-            messages = []
-            if sushy_task.messages and not sushy_task.messages[0].message:
-                sushy_task.parse_messages()
-
-            messages = [m.message for m in sushy_task.messages]
-
-            if (sushy_task.task_state == sushy.TASK_STATE_COMPLETED
-                    and sushy_task.task_status in
-                    [sushy.HEALTH_OK, sushy.HEALTH_WARNING]):
-                LOG.info('RAID %(operation)s task %(task_mon_uri)s to node '
-                         '%(node_uuid)s completed.',
-                         {'operation': operation,
-                          'task_mon_uri': task_monitor.task_monitor_uri,
-                          'node_uuid': task.node.uuid})
-            else:
-                LOG.error('RAID %(operation)s task %(task_mon_uri)s to node '
-                          '%(node_uuid)s failed; messages: %(messages)s',
-                          {'operation': operation,
-                           'task_mon_uri': task_monitor.task_monitor_uri,
-                           'node_uuid': task.node.uuid,
-                           'messages': ", ".join(messages)})
+            response = task_monitor.response
+            if response is not None:
+                status_code = response.status_code
+                if status_code >= 400:
+                    messages = self._get_error_messages(response)
+                    LOG.error('RAID %(operation)s task to node '
+                              '%(node_uuid)s failed with status '
+                              '%(status_code)s; messages: %(messages)s',
+                              {'operation': raid_config['operation'],
+                               'node_uuid': task.node.uuid,
+                               'status_code': status_code,
+                               'messages': ", ".join(messages)})
+                else:
+                    LOG.info('RAID %(operation)s task to node '
+                             '%(node_uuid)s completed with status '
+                             '%(status_code)s',
+                             {'operation': raid_config['operation'],
+                              'node_uuid': task.node.uuid,
+                              'status_code': status_code})
         return False
 
     @METRICS.timer('RedfishRAID._check_node_raid_config')
     def _check_node_raid_config(self, task):
-        """Check the progress of running RAID config on a node.
-
-        :param task: TaskManager object containing the node.
-        """
+        """Check the progress of running RAID config on a node."""
         node = task.node
         raid_configs = node.driver_internal_info['raid_configs']
 
         task.upgrade_lock()
-        raid_configs['task_monitor_uri'] =\
-            [i for i in raid_configs.get('task_monitor_uri')
-             if self._raid_config_in_progress(
-                task, i, raid_configs.get('operation'))]
-        info = node.driver_internal_info
-        info['raid_configs'] = raid_configs
-        node.driver_internal_info = info
+        raid_configs[:] = [i for i in raid_configs
+                           if self._raid_config_in_progress(task, i)]
 
-        if not raid_configs['task_monitor_uri']:
-            if raid_configs.get('pending'):
-                if raid_configs.get('operation') == 'create':
-                    reboot_required = self._submit_create_configuration(
-                        task, raid_configs.get('pending'))[1]
-                else:
-                    reboot_required = self._submit_delete_configuration(
-                        task)[1]
-                if reboot_required:
-                    deploy_utils.get_async_step_return_state(task.node)
-                    deploy_opts = deploy_utils.build_agent_options(task.node)
-                    task.driver.boot.prepare_ramdisk(task, deploy_opts)
-                    manager_utils.node_power_action(task, states.REBOOT)
-            else:
-                self._clear_raid_configs(node)
-                LOG.info('RAID configuration completed for node %(node)s',
-                         {'node': node.uuid})
-                update_raid_config(task.node)
-                if task.node.clean_step:
-                    manager_utils.notify_conductor_resume_clean(task)
-                else:
-                    manager_utils.notify_conductor_resume_deploy(task)
-
-    def _submit_create_configuration(self, task, ld_grouped):
-        """Processes and submits requests for creating RAID configuration.
-
-        :param task: TaskManager object containing the node.
-        :param ld_grouped: Dictionary of logical disks, grouped by controller.
-
-        :returns: tuple of 1) dictionary containing operation name (create),
-            pending items, and task monitor URIs, and 2) flag indicating if
-            reboot is required.
-        """
-        node = task.node
-        reboot_required = False
-        raid_configs = {'operation': 'create', 'pending': {}}
-        for controller, logical_disks in ld_grouped.items():
-            iter_logical_disks = iter(logical_disks)
-            for logical_disk in iter_logical_disks:
-                response = create_virtual_disk(
-                    task,
-                    raid_controller=logical_disk.get('controller'),
-                    physical_disks=logical_disk['physical_disks'],
-                    raid_level=logical_disk['raid_level'],
-                    size_bytes=logical_disk['size_bytes'],
-                    disk_name=logical_disk.get('name'),
-                    span_length=logical_disk.get('span_length'),
-                    span_depth=logical_disk.get('span_depth'),
-                    error_handler=self.volume_create_error_handler)
-                if (response is not None
-                        and hasattr(response, 'task_monitor_uri')):
-                    raid_configs.setdefault('task_monitor_uri', []).append(
-                        response.task_monitor_uri)
-                    reboot_required = True
-                    # Don't process any on this controller until these
-                    # created to avoid failures where only 1 request
-                    # per controller can be submitted for non-immediate
-                    break
-            # Append remaining disks for this controller, if any left
-            for logical_disk in iter_logical_disks:
-                raid_configs['pending'].setdefault(controller, []).append(
-                    logical_disk)
-
-        info = node.driver_internal_info
-        info['raid_configs'] = raid_configs
-        node.driver_internal_info = info
-
-        return raid_configs, reboot_required
-
-    def _submit_delete_configuration(self, task):
-        """Processes and submits requests for deleting virtual disks.
-
-        :param task: TaskManager object containing the node.
-
-        :returns: tuple of 1) dictionary containing operation name (delete),
-            flag to indicate if any disks remaining, and task monitor URIs,
-            and 2) flag indicating if reboot is required
-        :raises RedfishError: if fails to get list of virtual disks
-        """
-        node = task.node
-        system = redfish_utils.get_system(node)
-        vols_to_delete = {}
-        any_left = False
-        try:
-            for storage in system.storage.get_members():
-                controller = (storage.storage_controllers[0]
-                              if storage.storage_controllers else None)
-                controller_id = None
-                if controller:
-                    controller_id = storage.identity
-                iter_volumes = iter(storage.volumes.get_members())
-                for volume in iter_volumes:
-                    if (volume.raid_type or volume.volume_type not in
-                            [None, sushy.VOLUME_TYPE_RAW_DEVICE]):
-                        if controller_id not in vols_to_delete:
-                            vols_to_delete[controller_id] = []
-                        apply_time = self._get_apply_time(
-                            storage.volumes.operation_apply_time_support)
-                        vols_to_delete[controller_id].append((
-                            apply_time, volume))
-                        if apply_time == sushy.APPLY_TIME_ON_RESET:
-                            # Don't process any on this controller until these
-                            # deleted to avoid failures where only 1 request
-                            # per controller can be submitted for non-immediate
-                            break
-                any_left = any(iter_volumes)
-        except sushy.exceptions.SushyError as exc:
-            error_msg = _('Cannot get the list of volumes to delete for node '
-                          '%(node_uuid)s. Reason: %(error)s.' %
-                          {'node_uuid': node.uuid, 'error': exc})
-            LOG.error(error_msg)
-            raise exception.RedfishError(error=exc)
-
-        self.pre_delete_configuration(task, vols_to_delete)
-
-        reboot_required = False
-        raid_configs = {'operation': 'delete', 'pending': any_left}
-        for controller, vols_to_delete in vols_to_delete.items():
-            for apply_time, volume in vols_to_delete:
-                response = volume.delete(apply_time=apply_time)
-                # only save the async tasks (task_monitors) in raid_config
-                if (response is not None
-                        and hasattr(response, 'task_monitor_uri')):
-                    raid_configs.setdefault('task_monitor_uri', []).append(
-                        response.task_monitor_uri)
-                    reboot_required = True
-
-        info = node.driver_internal_info
-        info['raid_configs'] = raid_configs
-        node.driver_internal_info = info
-
-        return raid_configs, reboot_required
-
-    def _get_apply_time(self, apply_time_support):
-        """Gets apply time for RAID operations
-
-        :param apply_time_support: Supported apply times
-        :returns: None, if supported apply times not specified. Otherwise
-            Immediate when available, or OnReset that will require rebooting.
-        """
-        apply_time = None
-        if apply_time_support and apply_time_support.mapped_supported_values:
-            supported_values = apply_time_support.mapped_supported_values
-            if sushy.APPLY_TIME_IMMEDIATE in supported_values:
-                apply_time = sushy.APPLY_TIME_IMMEDIATE
-            elif sushy.APPLY_TIME_ON_RESET in supported_values:
-                apply_time = sushy.APPLY_TIME_ON_RESET
-        return apply_time
+        if not raid_configs:
+            self._clear_raid_configs(node)
+            LOG.info('RAID configuration completed for node %(node)s',
+                     {'node': node.uuid})
+            manager_utils.notify_conductor_resume_clean(task)
