@@ -234,16 +234,6 @@ class SessionCache(object):
         # NOTE(etingof): perhaps this session token is no good
         if isinstance(exc_val, sushy.exceptions.ConnectionError):
             self.__class__._sessions.pop(self._session_key, None)
-        # NOTE(TheJulia): A hard access error has surfaced, we
-        # likely need to eliminate the session.
-        if isinstance(exc_val, sushy.exceptions.AccessError):
-            self.__class__._sessions.pop(self._session_key, None)
-        # NOTE(TheJulia): Something very bad has happened, such
-        # as the session is out of date, and refresh of the SessionService
-        # failed resulting in an AttributeError surfacing.
-        # https://storyboard.openstack.org/#!/story/2009719
-        if isinstance(exc_val, AttributeError):
-            self.__class__._sessions.pop(self._session_key, None)
 
     @classmethod
     def _expire_oldest_session(cls):
@@ -351,23 +341,6 @@ def _get_connection(node, lambda_fun, *args):
                          'auth_type': driver_info['auth_type'],
                          'node': node.uuid, 'error': e})
             raise exception.RedfishConnectionError(node=node.uuid, error=e)
-        except sushy.exceptions.AccessError as e:
-            LOG.warning('For node %(node)s, we received an authentication '
-                        'access error from address %(address)s with auth_type '
-                        '%(auth_type)s. The client will not be re-used upon '
-                        'the next re-attempt. Please ensure your using the '
-                        'correct credentials. Error: %(error)s',
-                        {'address': driver_info['address'],
-                         'auth_type': driver_info['auth_type'],
-                         'node': node.uuid, 'error': e})
-            raise exception.RedfishError(node=node.uuid, error=e)
-        except AttributeError as e:
-            LOG.warning('For node %(node)s, we received at AttributeError '
-                        'when attempting to utilize the client. A new '
-                        'client session shall be used upon the next attempt.'
-                        'Attribute Error: %(error)s',
-                        {'node': node.uuid, 'error': e})
-            raise exception.RedfishError(node=node.uuid, error=e)
 
     try:
         return _get_cached_connection(lambda_fun, *args)
@@ -388,47 +361,42 @@ def get_enabled_macs(task, system):
         in a {'mac': 'state'} format
     """
 
-    enabled_macs = {}
     if (system.ethernet_interfaces
             and system.ethernet_interfaces.summary):
         macs = system.ethernet_interfaces.summary
 
         # Identify ports for the NICs being in 'enabled' state
-        for nic_mac, nic_state in macs.items():
-            if nic_state != sushy.STATE_ENABLED:
-                continue
-            elif not nic_mac:
-                LOG.warning("Ignoring device for %(node)s as no MAC "
-                            "reported", {'node': task.node.uuid})
-                continue
-            enabled_macs[nic_mac] = nic_state
-        if enabled_macs:
-            return enabled_macs
-
-    LOG.debug("No ethernet interface information is available "
-              "for node %(node)s", {'node': task.node.uuid})
+        enabled_macs = {nic_mac: nic_state
+                        for nic_mac, nic_state in macs.items()
+                        if nic_state == sushy.STATE_ENABLED}
+        return enabled_macs
+    else:
+        LOG.debug("No ethernet interface information is available "
+                  "for node %(node)s", {'node': task.node.uuid})
 
 
-@tenacity.retry(
-    retry=tenacity.retry_if_exception_type(
-        exception.RedfishConnectionError),
-    stop=tenacity.stop_after_attempt(CONF.redfish.connection_attempts),
-    wait=tenacity.wait_fixed(CONF.redfish.connection_retry_interval),
-    reraise=True)
 def wait_until_get_system_ready(node):
     """Wait until Redfish system is ready.
 
     :param node: an Ironic node object
     :raises: RedfishConnectionError on time out.
     """
+    @tenacity.retry(
+        retry=tenacity.retry_if_exception_type(
+            exception.RedfishConnectionError),
+        stop=tenacity.stop_after_attempt(CONF.redfish.connection_attempts),
+        wait=tenacity.wait_fixed(CONF.redfish.connection_retry_interval),
+        reraise=True)
+    def _get_system(driver_info, system_id):
+        try:
+            with SessionCache(driver_info) as conn:
+                return conn.get_system(system_id)
+        except sushy.exceptions.BadRequestError as e:
+            err_msg = ("System is not ready for node %(node)s, with error"
+                       "%(error)s, so retrying it",
+                       {'node': node.uuid, 'error': e})
+            LOG.warning(err_msg)
+            raise exception.RedfishConnectionError(node=node.uuid, error=e)
     driver_info = parse_driver_info(node)
     system_id = driver_info['system_id']
-    try:
-        with SessionCache(driver_info) as conn:
-            return conn.get_system(system_id)
-    except sushy.exceptions.BadRequestError as e:
-        err_msg = ("System is not ready for node %(node)s, with error"
-                   "%(error)s, so retrying it",
-                   {'node': node.uuid, 'error': e})
-        LOG.warning(err_msg)
-        raise exception.RedfishConnectionError(node=node.uuid, error=e)
+    return _get_system(driver_info, system_id)
