@@ -382,13 +382,55 @@ class IloManagementTestCase(test_common.BaseIloTest):
                                   **activate_license_args)
                 self.assertFalse(step_mock.called)
 
+    @mock.patch.object(ilo_management, '_execute_ilo_step',
+                       spec_set=True, autospec=True)
+    def test_security_parameters_update(self, step_mock):
+        security_parameters = [
+            {
+                "param": "password_complexity",
+                "enable": True,
+                "ignore": False
+            }
+        ]
+        security_parameters_args = {
+            'security_parameters': security_parameters}
+
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=False) as task:
+            task.driver.management.security_parameters_update(
+                task, **security_parameters_args)
+            step_mock.assert_called_once_with(
+                task.node, 'update_password_complexity', True, False)
+
+    @mock.patch.object(ilo_management, '_execute_ilo_step',
+                       spec_set=True, autospec=True)
+    def test_update_minimum_password_length(self, step_mock):
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=False) as task:
+            minimum_password_args = {'password_length': '8'}
+            task.driver.management.update_minimum_password_length(
+                task, **minimum_password_args)
+            step_mock.assert_called_once_with(
+                task.node, 'update_minimum_password_length', '8', False)
+
+    @mock.patch.object(ilo_management, '_execute_ilo_step',
+                       spec_set=True, autospec=True)
+    def test_update_auth_failure_logging_threshold(self, step_mock):
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=False) as task:
+            auth_failure_args = {'logging_threshold': '1'}
+            task.driver.management.update_auth_failure_logging_threshold(
+                task, **auth_failure_args)
+            step_mock.assert_called_once_with(
+                task.node, 'update_authentication_failure_logging', '1', False)
+
     @mock.patch.object(deploy_utils, 'build_agent_options',
                        spec_set=True, autospec=True)
     @mock.patch.object(ilo_boot.IloVirtualMediaBoot, 'clean_up_ramdisk',
                        spec_set=True, autospec=True)
     @mock.patch.object(ilo_boot.IloVirtualMediaBoot, 'prepare_ramdisk',
                        spec_set=True, autospec=True)
-    @mock.patch.object(ilo_management, 'LOG')
+    @mock.patch.object(ilo_management, 'LOG', autospec=True)
     @mock.patch.object(ilo_management, '_execute_ilo_step',
                        spec_set=True, autospec=True)
     @mock.patch.object(ilo_management.firmware_processor, 'FirmwareProcessor',
@@ -621,7 +663,7 @@ class IloManagementTestCase(test_common.BaseIloTest):
         self.node.save()
         self._test_update_firmware_throws_error_for_invalid_component_type()
 
-    @mock.patch.object(ilo_management, 'LOG')
+    @mock.patch.object(ilo_management, 'LOG', autospec=True)
     @mock.patch.object(ilo_management.firmware_processor.FirmwareProcessor,
                        'process_fw_on', spec_set=True, autospec=True)
     def _test_update_firmware_throws_error_for_checksum_validation_error(
@@ -744,7 +786,7 @@ class IloManagementTestCase(test_common.BaseIloTest):
         self.node.save()
         self._test_update_firmware_doesnt_update_any_if_any_url_fails()
 
-    @mock.patch.object(ilo_management, 'LOG')
+    @mock.patch.object(ilo_management, 'LOG', autospec=True)
     @mock.patch.object(ilo_management, '_execute_ilo_step',
                        spec_set=True, autospec=True)
     @mock.patch.object(ilo_management.firmware_processor, 'FirmwareProcessor',
@@ -983,7 +1025,7 @@ class IloManagementTestCase(test_common.BaseIloTest):
         self._test_write_firmware_sum_mode_invalid_component(
             step_type='deploy')
 
-    @mock.patch.object(driver_utils, 'store_ramdisk_logs')
+    @mock.patch.object(driver_utils, 'store_ramdisk_logs', autospec=True)
     def _test__write_firmware_sum_final_with_logs(self, store_mock,
                                                   step_type='clean'):
         self.config(deploy_logs_collect='always', group='agent')
@@ -1028,7 +1070,7 @@ class IloManagementTestCase(test_common.BaseIloTest):
     def test__write_firmware_sum_final_with_logs_deploy(self):
         self._test__write_firmware_sum_final_with_logs(step_type='deploy')
 
-    @mock.patch.object(driver_utils, 'store_ramdisk_logs')
+    @mock.patch.object(driver_utils, 'store_ramdisk_logs', autospec=True)
     def _test__write_firmware_sum_final_without_logs(self, store_mock,
                                                      step_type='clean'):
         self.config(deploy_logs_collect='on_failure', group='agent')
@@ -1068,7 +1110,7 @@ class IloManagementTestCase(test_common.BaseIloTest):
         self._test__write_firmware_sum_final_without_logs(step_type='deploy')
 
     @mock.patch.object(ilo_management, 'LOG', spec_set=True, autospec=True)
-    @mock.patch.object(driver_utils, 'store_ramdisk_logs')
+    @mock.patch.object(driver_utils, 'store_ramdisk_logs', autospec=True)
     def _test__write_firmware_sum_final_swift_error(self, store_mock,
                                                     log_mock,
                                                     step_type='clean'):
@@ -1114,7 +1156,7 @@ class IloManagementTestCase(test_common.BaseIloTest):
         self._test__write_firmware_sum_final_swift_error(step_type='deploy')
 
     @mock.patch.object(ilo_management, 'LOG', spec_set=True, autospec=True)
-    @mock.patch.object(driver_utils, 'store_ramdisk_logs')
+    @mock.patch.object(driver_utils, 'store_ramdisk_logs', autospec=True)
     def _test__write_firmware_sum_final_environment_error(self, store_mock,
                                                           log_mock,
                                                           step_type='clean'):
@@ -1162,7 +1204,7 @@ class IloManagementTestCase(test_common.BaseIloTest):
             step_type='deploy')
 
     @mock.patch.object(ilo_management, 'LOG', spec_set=True, autospec=True)
-    @mock.patch.object(driver_utils, 'store_ramdisk_logs')
+    @mock.patch.object(driver_utils, 'store_ramdisk_logs', autospec=True)
     def _test__write_firmware_sum_final_unknown_exception(self, store_mock,
                                                           log_mock,
                                                           step_type='clean'):
@@ -1493,7 +1535,7 @@ class Ilo5ManagementTestCase(db_base.DbTestCase):
         self.config(enabled_hardware_types=['ilo5'],
                     enabled_boot_interfaces=['ilo-virtual-media'],
                     enabled_console_interfaces=['ilo'],
-                    enabled_deploy_interfaces=['iscsi'],
+                    enabled_deploy_interfaces=['direct'],
                     enabled_inspect_interfaces=['ilo'],
                     enabled_management_interfaces=['ilo5'],
                     enabled_power_interfaces=['ilo'],
@@ -1584,7 +1626,7 @@ class Ilo5ManagementTestCase(db_base.DbTestCase):
             self.assertEqual(states.CLEANWAIT, result)
             mock_power.assert_called_once_with(task, states.REBOOT)
 
-    @mock.patch.object(ilo_management.LOG, 'info')
+    @mock.patch.object(ilo_management.LOG, 'info', autospec=True)
     @mock.patch.object(ilo_management.Ilo5Management,
                        '_wait_for_disk_erase_status', autospec=True)
     @mock.patch.object(ilo_common, 'get_ilo_object', autospec=True)
@@ -1634,7 +1676,7 @@ class Ilo5ManagementTestCase(db_base.DbTestCase):
             self.assertEqual(states.CLEANWAIT, result)
             mock_power.assert_called_once_with(task, states.REBOOT)
 
-    @mock.patch.object(ilo_management.LOG, 'info')
+    @mock.patch.object(ilo_management.LOG, 'info', autospec=True)
     @mock.patch.object(ilo_common, 'get_ilo_object', autospec=True)
     def test_erase_devices_when_no_drive_available(
             self, ilo_mock, log_mock):
@@ -1670,8 +1712,9 @@ class Ilo5ManagementTestCase(db_base.DbTestCase):
                               task, erase_pattern={'ssd': 'xyz'})
 
     @mock.patch.object(ilo_common, 'get_ilo_object', autospec=True)
-    @mock.patch.object(ilo_management.Ilo5Management, '_set_clean_failed')
-    def test_erase_devices_hdd_ilo_error(self, set_clean_failed_mock,
+    @mock.patch.object(manager_utils, 'cleaning_error_handler',
+                       autospec=True)
+    def test_erase_devices_hdd_ilo_error(self, clean_err_handler_mock,
                                          ilo_mock):
         ilo_mock_object = ilo_mock.return_value
         ilo_mock_object.get_available_disk_types.return_value = ['HDD']
@@ -1690,5 +1733,46 @@ class Ilo5ManagementTestCase(db_base.DbTestCase):
                              task.node.driver_internal_info)
             self.assertNotIn('skip_current_clean_step',
                              task.node.driver_internal_info)
-            set_clean_failed_mock.assert_called_once_with(
-                task, exc)
+            clean_err_handler_mock.assert_called_once_with(
+                task,
+                ("Out-of-band sanitize disk erase job failed for node %s. "
+                 "Message: 'error'." % task.node.uuid),
+                errmsg=exc)
+
+    @mock.patch.object(manager_utils, 'node_power_action', autospec=True)
+    @mock.patch.object(ilo_common, 'get_ilo_object', autospec=True)
+    def test_one_button_secure_erase(self, ilo_mock, mock_power):
+        ilo_mock_object = ilo_mock.return_value
+        self.node.clean_step = {'step': 'one_button_secure_erase',
+                                'interface': 'management'}
+        self.node.save()
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=False) as task:
+            result = task.driver.management.one_button_secure_erase(task)
+            self.assertTrue(
+                ilo_mock_object.do_one_button_secure_erase.called)
+            self.assertEqual(states.CLEANWAIT, result)
+            mock_power.assert_called_once_with(task, states.REBOOT)
+            self.assertEqual(task.node.maintenance, True)
+
+    @mock.patch.object(ilo_common, 'get_ilo_object', autospec=True)
+    @mock.patch.object(manager_utils, 'cleaning_error_handler',
+                       autospec=True)
+    def test_one_button_secure_erase_ilo_error(
+            self, clean_err_handler_mock, ilo_mock):
+        ilo_mock_object = ilo_mock.return_value
+        self.node.clean_step = {'step': 'one_button_secure_erase',
+                                'interface': 'management'}
+        self.node.save()
+        exc = ilo_error.IloError('error')
+        ilo_mock_object.do_one_button_secure_erase.side_effect = exc
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=False) as task:
+            task.driver.management.one_button_secure_erase(task)
+            clean_err_handler_mock.assert_called_once_with(
+                task,
+                ("One button secure erase job failed for node %s. "
+                 "Message: 'error'." % task.node.uuid),
+                errmsg=exc)
+            self.assertTrue(
+                ilo_mock_object.do_one_button_secure_erase.called)
