@@ -13,7 +13,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import collections
 import os
 import tempfile
 from unittest import mock
@@ -21,10 +20,8 @@ from unittest import mock
 from oslo_utils import importutils
 
 from ironic.common import images
-from ironic.common import states
 from ironic.common import utils
 from ironic.conductor import task_manager
-from ironic.drivers.modules import deploy_utils
 from ironic.drivers.modules import image_utils
 from ironic.tests.unit.db import base as db_base
 from ironic.tests.unit.db import utils as db_utils
@@ -241,8 +238,7 @@ class RedfishImageUtilsTestCase(db_base.DbTestCase):
                     enabled_inspect_interfaces=['redfish'],
                     enabled_bios_interfaces=['redfish'])
         self.node = obj_utils.create_test_node(
-            self.context, driver='redfish', driver_info=INFO_DICT,
-            provision_state=states.DEPLOYING)
+            self.context, driver='redfish', driver_info=INFO_DICT)
 
     @mock.patch.object(image_utils.ImageHandler, 'unpublish_image',
                        autospec=True)
@@ -557,66 +553,16 @@ class RedfishImageUtilsTestCase(db_base.DbTestCase):
                 root_uuid='1be26c0b-03f2-4d2e-ae87-c02d7f33c123',
                 base_iso='/path/to/baseiso', inject_files=None)
 
-    @mock.patch.object(deploy_utils, 'get_boot_option', lambda node: 'ramdisk')
     @mock.patch.object(image_utils.ImageHandler, 'publish_image',
                        autospec=True)
     @mock.patch.object(images, 'create_boot_iso', autospec=True)
-    def test__prepare_iso_image_kernel_params_for_ramdisk(
+    def test__prepare_iso_image_kernel_params_driver_info(
             self, mock_create_boot_iso, mock_publish_image):
         with task_manager.acquire(self.context, self.node.uuid,
                                   shared=True) as task:
             kernel_params = 'network-config=base64-cloudinit-blob'
 
-            task.node.instance_info['ramdisk_kernel_arguments'] = kernel_params
-
-            image_utils._prepare_iso_image(
-                task, 'http://kernel/img', 'http://ramdisk/img',
-                bootloader_href=None, root_uuid=task.node.uuid)
-
-            mock_create_boot_iso.assert_called_once_with(
-                mock.ANY, mock.ANY, 'http://kernel/img', 'http://ramdisk/img',
-                boot_mode='bios', esp_image_href=None,
-                kernel_params="root=/dev/ram0 text " + kernel_params,
-                root_uuid='1be26c0b-03f2-4d2e-ae87-c02d7f33c123',
-                base_iso=None, inject_files=None)
-
-    @mock.patch.object(deploy_utils, 'get_boot_option', lambda node: 'ramdisk')
-    @mock.patch.object(image_utils.ImageHandler, 'publish_image',
-                       autospec=True)
-    @mock.patch.object(images, 'create_boot_iso', autospec=True)
-    def test__prepare_iso_image_kernel_params_for_ramdisk_boot_iso(
-            self, mock_create_boot_iso, mock_publish_image):
-        with task_manager.acquire(self.context, self.node.uuid,
-                                  shared=True) as task:
-            kernel_params = 'network-config=base64-cloudinit-blob'
-
-            task.node.instance_info['ramdisk_kernel_arguments'] = kernel_params
-
-            image_utils._prepare_iso_image(
-                task, 'http://kernel/img', 'http://ramdisk/img',
-                bootloader_href=None, root_uuid=task.node.uuid,
-                base_iso='/path/to/baseiso')
-
-            mock_create_boot_iso.assert_called_once_with(
-                mock.ANY, mock.ANY, 'http://kernel/img', 'http://ramdisk/img',
-                boot_mode='bios', esp_image_href=None,
-                # No custom parameters with a boot ISO present
-                kernel_params=None,
-                root_uuid='1be26c0b-03f2-4d2e-ae87-c02d7f33c123',
-                base_iso='/path/to/baseiso', inject_files=None)
-
-    @mock.patch.object(deploy_utils, 'get_boot_option', lambda node: 'ramdisk')
-    @mock.patch.object(image_utils.ImageHandler, 'publish_image',
-                       autospec=True)
-    @mock.patch.object(images, 'create_boot_iso', autospec=True)
-    def test__prepare_iso_image_kernel_params_for_ramdisk_cleaning(
-            self, mock_create_boot_iso, mock_publish_image):
-        with task_manager.acquire(self.context, self.node.uuid,
-                                  shared=True) as task:
-            kernel_params = 'network-config=base64-cloudinit-blob'
-            self.config(kernel_append_params=kernel_params, group='redfish')
-
-            task.node.provision_state = states.CLEANING
+            task.node.driver_info['kernel_append_params'] = kernel_params
 
             image_utils._prepare_iso_image(
                 task, 'http://kernel/img', 'http://ramdisk/img',
@@ -630,29 +576,6 @@ class RedfishImageUtilsTestCase(db_base.DbTestCase):
                 root_uuid='1be26c0b-03f2-4d2e-ae87-c02d7f33c123',
                 base_iso='/path/to/baseiso', inject_files=None)
 
-    @mock.patch.object(image_utils.ImageHandler, 'publish_image',
-                       autospec=True)
-    @mock.patch.object(images, 'create_boot_iso', autospec=True)
-    def test__prepare_iso_image_extra_params(
-            self, mock_create_boot_iso, mock_publish_image):
-        with task_manager.acquire(self.context, self.node.uuid,
-                                  shared=True) as task:
-            kernel_params = 'network-config=base64-cloudinit-blob'
-            extra_params = collections.OrderedDict([('foo', 'bar'),
-                                                    ('banana', None)])
-            self.config(kernel_append_params=kernel_params, group='redfish')
-
-            image_utils._prepare_iso_image(
-                task, 'http://kernel/img', 'http://ramdisk/img',
-                root_uuid=task.node.uuid, params=extra_params)
-
-            mock_create_boot_iso.assert_called_once_with(
-                mock.ANY, mock.ANY, 'http://kernel/img', 'http://ramdisk/img',
-                boot_mode='bios', esp_image_href=None,
-                kernel_params=kernel_params + ' foo=bar banana',
-                root_uuid='1be26c0b-03f2-4d2e-ae87-c02d7f33c123',
-                base_iso=None, inject_files=None)
-
     def test__prepare_iso_image_bootable_iso(self):
         with task_manager.acquire(self.context, self.node.uuid,
                                   shared=True) as task:
@@ -727,6 +650,25 @@ class RedfishImageUtilsTestCase(db_base.DbTestCase):
 
     @mock.patch.object(image_utils, '_prepare_iso_image', autospec=True)
     def test_prepare_deploy_iso_existing_iso(self, mock__prepare_iso_image):
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=True) as task:
+
+            d_info = {
+                'deploy_iso': 'iso',
+            }
+            task.node.driver_info.update(d_info)
+
+            task.node.instance_info.update(deploy_boot_mode='uefi')
+
+            image_utils.prepare_deploy_iso(task, {}, 'deploy', d_info)
+
+            mock__prepare_iso_image.assert_called_once_with(
+                task, None, None, None, params={},
+                inject_files={}, base_iso='iso')
+
+    @mock.patch.object(image_utils, '_prepare_iso_image', autospec=True)
+    def test_prepare_deploy_iso_existing_iso_vendor_prefix(
+            self, mock__prepare_iso_image):
         with task_manager.acquire(self.context, self.node.uuid,
                                   shared=True) as task:
 
