@@ -78,8 +78,7 @@ class PXEBootTestCase(db_base.DbTestCase):
 
         self.config(enabled_boot_interfaces=[self.boot_interface,
                                              'ipxe', 'fake'])
-        self.config(enabled_deploy_interfaces=['fake', 'direct', 'iscsi',
-                                               'anaconda'])
+        self.config(enabled_deploy_interfaces=['fake', 'direct', 'anaconda'])
         self.node = obj_utils.create_test_node(
             self.context,
             driver=self.driver,
@@ -239,7 +238,7 @@ class PXEBootTestCase(db_base.DbTestCase):
 
     @mock.patch.object(deploy_utils, 'validate_image_properties',
                        autospec=True)
-    def test_validate_kickstart_has_stage2_id(self, mock_validate_img):
+    def test_validate_kickstart_has_squashfs_id(self, mock_validate_img):
         node = self.node
         node.deploy_interface = 'anaconda'
         node.save()
@@ -247,7 +246,7 @@ class PXEBootTestCase(db_base.DbTestCase):
         with task_manager.acquire(self.context, node.uuid) as task:
             task.driver.boot.validate(task)
             mock_validate_img.assert_called_once_with(
-                mock.ANY, mock.ANY, ['kernel_id', 'ramdisk_id', 'stage2_id']
+                mock.ANY, mock.ANY, ['kernel_id', 'ramdisk_id', 'squashfs_id']
             )
 
     def test_validate_kickstart_fail_http_url_not_set(self):
@@ -942,6 +941,8 @@ class PXERamdiskDeployTestCase(db_base.DbTestCase):
         with task_manager.acquire(self.context, node.uuid) as task:
             task.driver.deploy.prepare(task)
             self.assertFalse(mock_prepare_instance.called)
+            self.assertEqual({'boot_option': 'ramdisk'},
+                             task.node.instance_info['capabilities'])
 
     @mock.patch.object(pxe.PXEBoot, 'prepare_instance', autospec=True)
     def test_prepare_active(self, mock_prepare_instance):
@@ -961,6 +962,22 @@ class PXERamdiskDeployTestCase(db_base.DbTestCase):
             task.driver.deploy.prepare(task)
             mock_prepare_instance.assert_called_once_with(mock.ANY, task)
 
+    @mock.patch.object(pxe.LOG, 'warning', autospec=True)
+    @mock.patch.object(pxe.PXEBoot, 'prepare_instance', autospec=True)
+    def test_prepare_fixes_and_logs_boot_option_warning(
+            self, mock_prepare_instance, mock_warning):
+        node = self.node
+        node.properties['capabilities'] = 'boot_option:ramdisk'
+        node.provision_state = states.DEPLOYING
+        node.instance_info = {}
+        node.save()
+        with task_manager.acquire(self.context, node.uuid) as task:
+            task.driver.deploy.prepare(task)
+            self.assertFalse(mock_prepare_instance.called)
+            self.assertEqual({'boot_option': 'ramdisk'},
+                             task.node.instance_info['capabilities'])
+            self.assertTrue(mock_warning.called)
+
     @mock.patch.object(deploy_utils, 'validate_image_properties',
                        autospec=True)
     def test_validate(self, mock_validate_img):
@@ -1088,9 +1105,7 @@ class PXEAnacondaDeployTestCase(db_base.DbTestCase):
                       'ks_cfg': ('', '/path/to/ks_cfg')}
         mock_image_info.return_value = image_info
         with task_manager.acquire(self.context, self.node.uuid) as task:
-            self.assertEqual(
-                states.DEPLOYWAIT, task.driver.deploy.deploy(task)
-            )
+            self.assertIsNone(task.driver.deploy.deploy(task))
             mock_image_info.assert_called_once_with(task, ipxe_enabled=False)
             mock_cache.assert_called_once_with(
                 task, image_info, ipxe_enabled=False)
@@ -1099,23 +1114,15 @@ class PXEAnacondaDeployTestCase(db_base.DbTestCase):
             mock_prepare_ks_config.assert_called_once_with(task, image_info,
                                                            anaconda_boot=True)
 
-    @mock.patch.object(deploy_utils, 'build_instance_info_for_deploy',
-                       autospec=True)
     @mock.patch.object(pxe.PXEBoot, 'prepare_instance', autospec=True)
-    def test_prepare(self, mock_prepare_instance, mock_build_instance):
-
+    def test_prepare(self, mock_prepare_instance):
         node = self.node
         node.provision_state = states.DEPLOYING
         node.instance_info = {}
         node.save()
-        updated_instance_info = {'image_url': 'foo'}
-        mock_build_instance.return_value = updated_instance_info
         with task_manager.acquire(self.context, node.uuid) as task:
             task.driver.deploy.prepare(task)
             self.assertFalse(mock_prepare_instance.called)
-            mock_build_instance.assert_called_once_with(task)
-            node.refresh()
-            self.assertEqual(updated_instance_info, node.instance_info)
 
     @mock.patch.object(pxe.PXEBoot, 'prepare_instance', autospec=True)
     def test_prepare_active(self, mock_prepare_instance):
@@ -1137,8 +1144,6 @@ class PXEAnacondaDeployTestCase(db_base.DbTestCase):
                       'ks_template': ('', '/path/to/ks_template'),
                       'ks_cfg': ('', '/path/to/ks_cfg')}
         mock_image_info.return_value = image_info
-        self.node.provision_state = states.DEPLOYWAIT
-        self.node.save()
         with task_manager.acquire(self.context, self.node.uuid) as task:
             task.driver.deploy.reboot_to_instance(task)
             mock_set_boot_dev.assert_called_once_with(task, boot_devices.DISK)
@@ -1201,17 +1206,6 @@ class PXEAnacondaDeployTestCase(db_base.DbTestCase):
                 task.node.driver_internal_info['agent_status'])
             self.assertTrue(mock_reboot_to_instance.called)
 
-    @mock.patch.object(deploy_utils, 'prepare_inband_cleaning', autospec=True)
-    def test_prepare_cleaning(self, prepare_inband_cleaning_mock):
-        prepare_inband_cleaning_mock.return_value = states.CLEANWAIT
-        self.node.provision_state = states.CLEANING
-        self.node.save()
-        with task_manager.acquire(self.context, self.node.uuid) as task:
-            self.assertEqual(
-                states.CLEANWAIT, self.deploy.prepare_cleaning(task))
-            prepare_inband_cleaning_mock.assert_called_once_with(
-                task, manage_boot=True)
-
 
 class PXEValidateRescueTestCase(db_base.DbTestCase):
 
