@@ -99,20 +99,11 @@ if not dracclient:
         spec_set=mock_specs.DRACCLIENT_CONSTANTS_RAID_STATUS_MOD_SPEC,
         jbod=mock.sentinel.jbod,
         raid=mock.sentinel.raid)
-    dracclient.resources.uris = mock.MagicMock(
-        spec_set=mock_specs.DRACCLIENT_RESOURCES_URIS_MOD_SPEC,
-        DCIM_SystemView=mock.sentinel.DCIM_SystemView
-    )
-    dracclient.utils = mock.MagicMock(
-        spec_set=mock_specs.DRACCLIENT_UTILS_MOD_SPEC
-    )
 
     sys.modules['dracclient'] = dracclient
     sys.modules['dracclient.client'] = dracclient.client
     sys.modules['dracclient.constants'] = dracclient.constants
     sys.modules['dracclient.exceptions'] = dracclient.exceptions
-    sys.modules['dracclient.resources.uris'] = dracclient.resources.uris
-    sys.modules['dracclient.utils'] = dracclient.utils
     dracclient.exceptions.BaseClientException = type('BaseClientException',
                                                      (Exception,), {})
 
@@ -221,9 +212,6 @@ if not sushy:
         PROCESSOR_ARCH_ARM='ARM',
         PROCESSOR_ARCH_MIPS='MIPS',
         PROCESSOR_ARCH_OEM='OEM-defined',
-        PROTOCOL_TYPE_iSCSI='Internet SCSI',
-        PROTOCOL_TYPE_SAS='Serial Attached SCSI',
-        PROTOCOL_TYPE_SATA='Serial AT Attachment',
         STATE_ENABLED='enabled',
         STATE_DISABLED='disabled',
         STATE_ABSENT='absent',
@@ -237,10 +225,7 @@ if not sushy:
         HEALTH_WARNING='warning',
         SECURE_BOOT_RESET_KEYS_TO_DEFAULT="ResetAllKeysToDefault",
         SECURE_BOOT_RESET_KEYS_DELETE_ALL="DeleteAllKeys",
-        VOLUME_TYPE_RAW_DEVICE='rawdevice',
-        SEVERITY_OK='ok',
-        SEVERITY_WARNING='warning',
-        SEVERITY_CRITICAL='critical'
+        VOLUME_TYPE_RAW_DEVICE='rawdevice'
     )
 
     sys.modules['sushy'] = sushy
