@@ -15,9 +15,9 @@
 import contextlib
 import datetime
 import types
+from unittest import mock
 
 import iso8601
-import mock
 from oslo_utils import timeutils
 from oslo_versionedobjects import base as object_base
 from oslo_versionedobjects import exception as object_exception
@@ -676,10 +676,10 @@ class TestObject(_LocalTest, _TestObject):
 # version bump. It is an MD5 hash of the object fields and remotable methods.
 # The fingerprint values should only be changed if there is a version bump.
 expected_object_fingerprints = {
-    'Node': '1.34-ae873e627cf30bf28fe9f98a807b6200',
+    'Node': '1.35-aee8ecf5c4d0ed590eb484762aee7fca',
     'MyObj': '1.5-9459d30d6954bffc7a9afd347a807ca6',
     'Chassis': '1.3-d656e039fd8ae9f34efc232ab3980905',
-    'Port': '1.9-0cb9202a4ec442e8c0d87a324155eaaf',
+    'Port': '1.10-67381b065c597c8d3a13c5dbc6243c33',
     'Portgroup': '1.4-71923a81a86743b313b190f5c675e258',
     'Conductor': '1.3-d3f53e853b4d58cae5bfbd9a8341af4a',
     'EventType': '1.1-aa2ba1afd38553e3880c267404e8d370',
@@ -692,7 +692,7 @@ expected_object_fingerprints = {
     'NodeCorrectedPowerStatePayload': '1.15-59a224a9191cdc9f1acc2e0dcd2d3adb',
     'NodeSetProvisionStateNotification':
         '1.0-59acc533c11d306f149846f922739c15',
-    'NodeSetProvisionStatePayload': '1.15-488a3d62a0643d17e288ecf89ed5bbb4',
+    'NodeSetProvisionStatePayload': '1.16-c5a8eea43c514baf721fc61ce5d9d5a4',
     'VolumeConnector': '1.0-3e0252c0ab6e6b9d158d09238a577d97',
     'VolumeTarget': '1.0-0b10d663d8dae675900b2c7548f76f5e',
     'ChassisCRUDNotification': '1.0-59acc533c11d306f149846f922739c15',
@@ -700,7 +700,7 @@ expected_object_fingerprints = {
     'NodeCRUDNotification': '1.0-59acc533c11d306f149846f922739c15',
     'NodeCRUDPayload': '1.13-8f673253ff8d7389897a6a80d224ac33',
     'PortCRUDNotification': '1.0-59acc533c11d306f149846f922739c15',
-    'PortCRUDPayload': '1.3-21235916ed54a91b2a122f59571194e7',
+    'PortCRUDPayload': '1.4-9411a1701077ae9dc0aea27d6bf586fc',
     'NodeMaintenanceNotification': '1.0-59acc533c11d306f149846f922739c15',
     'NodeConsoleNotification': '1.0-59acc533c11d306f149846f922739c15',
     'PortgroupCRUDNotification': '1.0-59acc533c11d306f149846f922739c15',
@@ -711,7 +711,7 @@ expected_object_fingerprints = {
     'VolumeTargetCRUDPayload': '1.0-30dcc4735512c104a3a36a2ae1e2aeb2',
     'Trait': '1.0-3f26cb70c8a10a3807d64c219453e347',
     'TraitList': '1.0-33a2e1bb91ad4082f9f63429b77c1244',
-    'BIOSSetting': '1.0-fd4a791dc2139a7cc21cefbbaedfd9e7',
+    'BIOSSetting': '1.1-1137db88675a4e2d7f7bcc3a0d52345a',
     'BIOSSettingList': '1.0-33a2e1bb91ad4082f9f63429b77c1244',
     'Allocation': '1.1-38937f2854722f1057ec667b12878708',
     'AllocationCRUDNotification': '1.0-59acc533c11d306f149846f922739c15',
@@ -719,6 +719,7 @@ expected_object_fingerprints = {
     'DeployTemplate': '1.1-4e30c8e9098595e359bb907f095bf1a9',
     'DeployTemplateCRUDNotification': '1.0-59acc533c11d306f149846f922739c15',
     'DeployTemplateCRUDPayload': '1.0-200857e7e715f58a5b6d6b700ab73a3b',
+    'Deployment': '1.0-ff10ae028c5968f1596131d85d7f5f9d',
 }
 
 
